'''OpenGL extension APPLE.vertex_array_range

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_APPLE_vertex_array_range'
_DEPRECATED = False
GL_VERTEX_ARRAY_RANGE_APPLE = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_APPLE', 0x851D )
GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE', 0x851E )
glget.addGLGetConstant( GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE, (1,) )
GL_VERTEX_ARRAY_STORAGE_HINT_APPLE = constant.Constant( 'GL_VERTEX_ARRAY_STORAGE_HINT_APPLE', 0x851F )
GL_VERTEX_ARRAY_RANGE_POINTER_APPLE = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_POINTER_APPLE', 0x8521 )
GL_STORAGE_CACHED_APPLE = constant.Constant( 'GL_STORAGE_CACHED_APPLE', 0x85BE )
GL_STORAGE_SHARED_APPLE = constant.Constant( 'GL_STORAGE_SHARED_APPLE', 0x85BF )
glVertexArrayRangeAPPLE = platform.createExtensionFunction( 
'glVertexArrayRangeAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,ctypes.c_void_p,),
doc='glVertexArrayRangeAPPLE(GLsizei(length), c_void_p(pointer)) -> None',
argNames=('length','pointer',),
deprecated=_DEPRECATED,
)

glFlushVertexArrayRangeAPPLE = platform.createExtensionFunction( 
'glFlushVertexArrayRangeAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,ctypes.c_void_p,),
doc='glFlushVertexArrayRangeAPPLE(GLsizei(length), c_void_p(pointer)) -> None',
argNames=('length','pointer',),
deprecated=_DEPRECATED,
)

glVertexArrayParameteriAPPLE = platform.createExtensionFunction( 
'glVertexArrayParameteriAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glVertexArrayParameteriAPPLE(GLenum(pname), GLint(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)


def glInitVertexArrayRangeAPPLE():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.flush_raster

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_flush_raster'
_DEPRECATED = False

glFlushRasterSGIX = platform.createExtensionFunction( 
'glFlushRasterSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glFlushRasterSGIX() -> None',
argNames=(),
deprecated=_DEPRECATED,
)


def glInitFlushRasterSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.draw_range_elements

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_draw_range_elements'
_DEPRECATED = False
GL_MAX_ELEMENTS_VERTICES_EXT = constant.Constant( 'GL_MAX_ELEMENTS_VERTICES_EXT', 0x80E8 )
GL_MAX_ELEMENTS_INDICES_EXT = constant.Constant( 'GL_MAX_ELEMENTS_INDICES_EXT', 0x80E9 )
glDrawRangeElementsEXT = platform.createExtensionFunction( 
'glDrawRangeElementsEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLsizei,constants.GLenum,ctypes.c_void_p,),
doc='glDrawRangeElementsEXT(GLenum(mode), GLuint(start), GLuint(end), GLsizei(count), GLenum(type), c_void_p(indices)) -> None',
argNames=('mode','start','end','count','type','indices',),
deprecated=_DEPRECATED,
)


def glInitDrawRangeElementsEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.GL_422_pixels

Overview (from the spec)
    
    This extension provides support for converting 422 pixels in host
    memory to 444 pixels as part of the pixel storage operation.
    
    The pixel unpack storage operation treats a 422 pixel as a 2 element
    format where the first element is C (chrominance) and the second
    element is L (luminance). Luminance is present on all pixels; a full
    chrominance value requires two pixels.
    
    The pixel pack storage operation converts RGB to a 422 pixel defined as
    a 2 element format where the first element stored is C (chrominance)
    and the second element stored is L (luminance).  Luminance is present
    on all pixels; a full chrominance value requires two pixels.
    
    Both averaging and non-averaging is supported for green and blue
    assignments for pack and unpack operations.

The official definition of this extension is available here:
    http://oss.sgi.com/projects/ogl-sample/registry/EXT/GL_422_pixels.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
GL_422_EXT = constant.Constant( 'GL_422_EXT', 0x80CC )
GL_422_REV_EXT = constant.Constant( 'GL_422_REV_EXT', 0x80CD )
GL_422_AVERAGE_EXT = constant.Constant( 'GL_422_AVERAGE_EXT', 0x80CE )
GL_422_REV_AVERAGE_EXT = constant.Constant( 'GL_422_REV_AVERAGE_EXT', 0x80CF )


def glInit422PixelsEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( 'GL_EXT_422_pixels' )


'''OpenGL extension VERSION.GL_2_0_DEPRECATED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_2_0'
_DEPRECATED = True
GL_VERTEX_PROGRAM_TWO_SIDE = constant.Constant( 'GL_VERTEX_PROGRAM_TWO_SIDE', 0x8643 )
GL_POINT_SPRITE = constant.Constant( 'GL_POINT_SPRITE', 0x8861 )
GL_COORD_REPLACE = constant.Constant( 'GL_COORD_REPLACE', 0x8862 )
GL_MAX_TEXTURE_COORDS = constant.Constant( 'GL_MAX_TEXTURE_COORDS', 0x8871 )




'''OpenGL extension EXT.texture_filter_anisotropic

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_filter_anisotropic'
_DEPRECATED = False
GL_TEXTURE_MAX_ANISOTROPY_EXT = constant.Constant( 'GL_TEXTURE_MAX_ANISOTROPY_EXT', 0x84FE )
GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT = constant.Constant( 'GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT', 0x84FF )
glget.addGLGetConstant( GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, (1,) )


def glInitTextureFilterAnisotropicEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.texgen_reflection

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_texgen_reflection'
_DEPRECATED = False
GL_NORMAL_MAP_NV = constant.Constant( 'GL_NORMAL_MAP_NV', 0x8511 )
GL_REFLECTION_MAP_NV = constant.Constant( 'GL_REFLECTION_MAP_NV', 0x8512 )


def glInitTexgenReflectionNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.separate_shader_objects

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.separate_shader_objects to provide a more 
Python-friendly API

Overview (from the spec)
	
	Prior to this extension, GLSL requires multiple shader domains
	(vertex, fragment, geometry) to be linked into a single monolithic
	program object to specify a GLSL shader for each domain.
	
	While GLSL's monolithic approach has some advantages for
	optimizing shaders as a unit that span multiple domains, all
	existing GPU hardware supports the more flexible mix-and-match
	approach.
	
	HLSL9, Cg, the prior OpenGL assembly program extensions, and game
	console programmers favor a more flexible "mix-and-match" approach to
	specifying shaders independently for these different shader domains.
	Many developers build their shader content around the mix-and-match
	approach where they can use a single vertex shader with multiple
	fragment shaders (or vice versa).
	
	This keep-it-simple extension adapts the "mix-and-match" shader
	domain model for GLSL so different GLSL program objects can be bound
	to different shader domains.
	
	This extension redefines the operation of glUseProgram(GLenum program)
	to be equivalent to:
	
	    glUseShaderProgramEXT(GL_VERTEX_SHADER, program);
	    glUseShaderProgramEXT(GL_GEOMETRY_SHADER_EXT, program);
	    glUseShaderProgramEXT(GL_FRAGMENT_SHADER, program);
	    glActiveProgramEXT(program);
	
	You can also call these commands separately to bind each respective
	domain.  The GL_VERTEX_SHADER, GL_GEOMETRY_SHADER_EXT, and
	GL_FRAGMENT_SHADER tokens refer to the conventional vertex, geometry,
	and fragment domains respectively.  glActiveProgramEXT specifies
	the program that glUniform* commands will update.
	
	Separate linking creates the possibility that certain output varyings
	of a shader may go unread by the subsequent shader inputting varyings.
	In this case, the output varyings are simply ignored.  It is also
	possible input varyings from a shader may not be written as output
	varyings of a preceding shader.  In this case, the unwritten input
	varying values are undefined.  Implementations are encouraged to
	zero these undefined input varying values.
	
	This extension is a proof-of-concept that separate shader objects
	can work for GLSL and a response to repeated requests for this
	functionality.  There are various loose ends, particularly when
	dealing with user-defined varyings.  The hope is a future extension
	will improve this situation.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/separate_shader_objects.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.separate_shader_objects import *
### END AUTOGENERATED SECTION


'''OpenGL extension VERSION.GL_3_2

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_3_2'
_DEPRECATED = False
GL_CONTEXT_CORE_PROFILE_BIT = constant.Constant( 'GL_CONTEXT_CORE_PROFILE_BIT', 0x1 )
GL_CONTEXT_COMPATIBILITY_PROFILE_BIT = constant.Constant( 'GL_CONTEXT_COMPATIBILITY_PROFILE_BIT', 0x2 )
GL_LINES_ADJACENCY = constant.Constant( 'GL_LINES_ADJACENCY', 0xA )
GL_LINE_STRIP_ADJACENCY = constant.Constant( 'GL_LINE_STRIP_ADJACENCY', 0xB )
GL_TRIANGLES_ADJACENCY = constant.Constant( 'GL_TRIANGLES_ADJACENCY', 0xC )
GL_TRIANGLE_STRIP_ADJACENCY = constant.Constant( 'GL_TRIANGLE_STRIP_ADJACENCY', 0xD )
GL_PROGRAM_POINT_SIZE = constant.Constant( 'GL_PROGRAM_POINT_SIZE', 0x8642 )
GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS = constant.Constant( 'GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS', 0x8C29 )
GL_FRAMEBUFFER_ATTACHMENT_LAYERED = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_LAYERED', 0x8DA7 )
GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS', 0x8DA8 )
GL_GEOMETRY_SHADER = constant.Constant( 'GL_GEOMETRY_SHADER', 0x8DD9 )
GL_GEOMETRY_VERTICES_OUT = constant.Constant( 'GL_GEOMETRY_VERTICES_OUT', 0x8916 )
GL_GEOMETRY_INPUT_TYPE = constant.Constant( 'GL_GEOMETRY_INPUT_TYPE', 0x8917 )
GL_GEOMETRY_OUTPUT_TYPE = constant.Constant( 'GL_GEOMETRY_OUTPUT_TYPE', 0x8918 )
GL_MAX_GEOMETRY_UNIFORM_COMPONENTS = constant.Constant( 'GL_MAX_GEOMETRY_UNIFORM_COMPONENTS', 0x8DDF )
GL_MAX_GEOMETRY_OUTPUT_VERTICES = constant.Constant( 'GL_MAX_GEOMETRY_OUTPUT_VERTICES', 0x8DE0 )
GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS = constant.Constant( 'GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS', 0x8DE1 )
GL_MAX_VERTEX_OUTPUT_COMPONENTS = constant.Constant( 'GL_MAX_VERTEX_OUTPUT_COMPONENTS', 0x9122 )
GL_MAX_GEOMETRY_INPUT_COMPONENTS = constant.Constant( 'GL_MAX_GEOMETRY_INPUT_COMPONENTS', 0x9123 )
GL_MAX_GEOMETRY_OUTPUT_COMPONENTS = constant.Constant( 'GL_MAX_GEOMETRY_OUTPUT_COMPONENTS', 0x9124 )
GL_MAX_FRAGMENT_INPUT_COMPONENTS = constant.Constant( 'GL_MAX_FRAGMENT_INPUT_COMPONENTS', 0x9125 )
GL_CONTEXT_PROFILE_MASK = constant.Constant( 'GL_CONTEXT_PROFILE_MASK', 0x9126 )
glGetInteger64i_v = platform.createExtensionFunction( 
'glGetInteger64i_v',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLint64Array,),
doc='glGetInteger64i_v(GLenum(target), GLuint(index), GLint64Array(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glGetBufferParameteri64v = platform.createExtensionFunction( 
'glGetBufferParameteri64v',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLint64Array,),
doc='glGetBufferParameteri64v(GLenum(target), GLenum(pname), GLint64Array(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glProgramParameteri = platform.createExtensionFunction( 
'glProgramParameteri',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,),
doc='glProgramParameteri(GLuint(program), GLenum(pname), GLint(value)) -> None',
argNames=('program','pname','value',),
deprecated=_DEPRECATED,
)

glFramebufferTexture = platform.createExtensionFunction( 
'glFramebufferTexture',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glFramebufferTexture(GLenum(target), GLenum(attachment), GLuint(texture), GLint(level)) -> None',
argNames=('target','attachment','texture','level',),
deprecated=_DEPRECATED,
)

glFramebufferTextureFace = platform.createExtensionFunction( 
'glFramebufferTextureFace',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,constants.GLenum,),
doc='glFramebufferTextureFace(GLenum(target), GLenum(attachment), GLuint(texture), GLint(level), GLenum(face)) -> None',
argNames=('target','attachment','texture','level','face',),
deprecated=_DEPRECATED,
)




'''OpenGL extension EXT.index_func

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_index_func'
_DEPRECATED = False
GL_INDEX_TEST_EXT = constant.Constant( 'GL_INDEX_TEST_EXT', 0x81B5 )
GL_INDEX_TEST_FUNC_EXT = constant.Constant( 'GL_INDEX_TEST_FUNC_EXT', 0x81B6 )
GL_INDEX_TEST_REF_EXT = constant.Constant( 'GL_INDEX_TEST_REF_EXT', 0x81B7 )
glIndexFuncEXT = platform.createExtensionFunction( 
'glIndexFuncEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLclampf,),
doc='glIndexFuncEXT(GLenum(func), GLclampf(ref)) -> None',
argNames=('func','ref',),
deprecated=_DEPRECATED,
)


def glInitIndexFuncEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.clipmap

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_clipmap'
_DEPRECATED = False
GL_LINEAR_CLIPMAP_LINEAR_SGIX = constant.Constant( 'GL_LINEAR_CLIPMAP_LINEAR_SGIX', 0x8170 )
GL_TEXTURE_CLIPMAP_CENTER_SGIX = constant.Constant( 'GL_TEXTURE_CLIPMAP_CENTER_SGIX', 0x8171 )
GL_TEXTURE_CLIPMAP_FRAME_SGIX = constant.Constant( 'GL_TEXTURE_CLIPMAP_FRAME_SGIX', 0x8172 )
GL_TEXTURE_CLIPMAP_OFFSET_SGIX = constant.Constant( 'GL_TEXTURE_CLIPMAP_OFFSET_SGIX', 0x8173 )
GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX = constant.Constant( 'GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX', 0x8174 )
GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX = constant.Constant( 'GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX', 0x8175 )
GL_TEXTURE_CLIPMAP_DEPTH_SGIX = constant.Constant( 'GL_TEXTURE_CLIPMAP_DEPTH_SGIX', 0x8176 )
GL_MAX_CLIPMAP_DEPTH_SGIX = constant.Constant( 'GL_MAX_CLIPMAP_DEPTH_SGIX', 0x8177 )
GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX = constant.Constant( 'GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX', 0x8178 )
GL_NEAREST_CLIPMAP_NEAREST_SGIX = constant.Constant( 'GL_NEAREST_CLIPMAP_NEAREST_SGIX', 0x844D )
GL_NEAREST_CLIPMAP_LINEAR_SGIX = constant.Constant( 'GL_NEAREST_CLIPMAP_LINEAR_SGIX', 0x844E )
GL_LINEAR_CLIPMAP_NEAREST_SGIX = constant.Constant( 'GL_LINEAR_CLIPMAP_NEAREST_SGIX', 0x844F )


def glInitClipmapSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.depth_buffer_float

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_depth_buffer_float'
_DEPRECATED = False
GL_DEPTH_COMPONENT32F = constant.Constant( 'GL_DEPTH_COMPONENT32F', 0x8CAC )
GL_DEPTH32F_STENCIL8 = constant.Constant( 'GL_DEPTH32F_STENCIL8', 0x8CAD )
GL_FLOAT_32_UNSIGNED_INT_24_8_REV = constant.Constant( 'GL_FLOAT_32_UNSIGNED_INT_24_8_REV', 0x8DAD )


def glInitDepthBufferFloatARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.vertex_program

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.vertex_program to provide a more 
Python-friendly API

Overview (from the spec)
	
	Unextended OpenGL mandates a certain set of configurable per-vertex
	computations defining vertex transformation, texture coordinate generation
	and transformation, and lighting.  Several extensions have added further
	per-vertex computations to OpenGL.  For example, extensions have defined
	new texture coordinate generation modes (ARB_texture_cube_map,
	NV_texgen_reflection, NV_texgen_emboss), new vertex transformation modes
	(ARB_vertex_blend, EXT_vertex_weighting), new lighting modes (OpenGL 1.2's
	separate specular and rescale normal functionality), several modes for fog
	distance generation (NV_fog_distance), and eye-distance point size
	attenuation (EXT/ARB_point_parameters).
	
	Each such extension adds a small set of relatively inflexible
	per-vertex computations.
	
	This inflexibility is in contrast to the typical flexibility provided by
	the underlying programmable floating point engines (whether micro-coded
	vertex engines, DSPs, or CPUs) that are traditionally used to implement
	OpenGL's per-vertex computations.  The purpose of this extension is to
	expose to the OpenGL application writer a significant degree of per-vertex
	programmability for computing vertex parameters.
	
	For the purposes of discussing this extension, a vertex program is a
	sequence of floating-point 4-component vector operations that determines
	how a set of program parameters (defined outside of OpenGL's Begin/End
	pair) and an input set of per-vertex parameters are transformed to a set
	of per-vertex result parameters.
	
	The per-vertex computations for standard OpenGL given a particular set of
	lighting and texture coordinate generation modes (along with any state for
	extensions defining per-vertex computations) is, in essence, a vertex
	program.  However, the sequence of operations is defined implicitly by the
	current OpenGL state settings rather than defined explicitly as a sequence
	of instructions.
	
	This extension provides an explicit mechanism for defining vertex program
	instruction sequences for application-defined vertex programs.  In order
	to define such vertex programs, this extension defines a vertex
	programming model including a floating-point 4-component vector
	instruction set and a relatively large set of floating-point 4-component
	registers.
	
	The extension's vertex programming model is designed for efficient
	hardware implementation and to support a wide variety of vertex programs.
	By design, the entire set of existing vertex programs defined by existing
	OpenGL per-vertex computation extensions can be implemented using the
	extension's vertex programming model.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/vertex_program.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.vertex_program import *
### END AUTOGENERATED SECTION
from OpenGL.lazywrapper import lazy

from OpenGL import converters, error, contextdata
from OpenGL.arrays.arraydatatype import ArrayDatatype
# Note: sizes here are == the only documented sizes I could find,
# may need a lookup table some day...
glGetProgramivARB = wrapper.wrapper(glGetProgramivARB).setOutput(
    'params', (1,),
)
glGetProgramEnvParameterdvARB = wrapper.wrapper(glGetProgramEnvParameterdvARB).setOutput(
    'params',(4,),
)
glGetProgramEnvParameterfvARB = wrapper.wrapper(glGetProgramEnvParameterfvARB).setOutput(
    'params',(4,),
)
glGetProgramLocalParameterdvARB = wrapper.wrapper(glGetProgramLocalParameterdvARB).setOutput(
    'params',(4,),
)
glGetProgramLocalParameterfvARB = wrapper.wrapper(glGetProgramLocalParameterfvARB).setOutput(
    'params',(4,),
)
glGetVertexAttribdvARB = wrapper.wrapper(glGetVertexAttribdvARB).setOutput(
    'params',(1,),
)

##glGetVertexAttribPointervARB = wrapper.wrapper(glGetVertexAttribPointervARB).setOutput(
##	'pointer',(1,),
##)
##
##_base_glGetVertexAttribPointervARB
##def glGetVertexAttribPointervARB( index, pname=GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB ):
##	"""Retrieve named attribute vector
##	
##	XXX Needs logic checking, I don't think I got the number of
##	levels of indirection correct... i.e. I believe it's just going
##	to rewrite the temporary void_p's value, rather than writing
##	into the numpy array.
##	
##	returns 4-element double array...
##	"""
##	output = arrays.GLdoubleArray.zeros( (4,) )
##	pointer = arrays.GLdoubleArray.voidDataPointer( output )
##	_base_glGetVertexAttribPointervARB( index, pname, pointer )
##	return output

@lazy( glVertexAttribPointerARB )
def glVertexAttribPointerARB( 
    baseOperation, index, size, type,
    normalized, stride, pointer,
):
    """Set an attribute pointer for a given shader (index)
    
    index -- the index of the generic vertex to bind, see 
        glGetAttribLocation for retrieval of the value,
        note that index is a global variable, not per-shader
    size -- number of basic elements per record, 1,2,3, or 4
    type -- enum constant for data-type 
    normalized -- whether to perform int to float 
        normalization on integer-type values
    stride -- stride in machine units (bytes) between 
        consecutive records, normally used to create 
        "interleaved" arrays 
    pointer -- data-pointer which provides the data-values,
        normally a vertex-buffer-object or offset into the 
        same.
    
    This implementation stores a copy of the data-pointer 
    in the contextdata structure in order to prevent null-
    reference errors in the renderer.
    """
    array = ArrayDatatype.asArray( pointer )
    key = ('vertex-attrib',index)
    contextdata.setValue( key, array )
    return baseOperation(
        index, size, type,
        normalized, stride, 
        ArrayDatatype.voidDataPointer( array ) 
    )


'''OpenGL extension ARB.fragment_shader

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_fragment_shader'
_DEPRECATED = False
GL_FRAGMENT_SHADER_ARB = constant.Constant( 'GL_FRAGMENT_SHADER_ARB', 0x8B30 )
GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB = constant.Constant( 'GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB', 0x8B49 )
glget.addGLGetConstant( GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB, (1,) )
GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB = constant.Constant( 'GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB', 0x8B8B )
glget.addGLGetConstant( GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB, (1,) )


def glInitFragmentShaderARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ATI.element_array

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_element_array'
_DEPRECATED = False
GL_ELEMENT_ARRAY_ATI = constant.Constant( 'GL_ELEMENT_ARRAY_ATI', 0x8768 )
GL_ELEMENT_ARRAY_TYPE_ATI = constant.Constant( 'GL_ELEMENT_ARRAY_TYPE_ATI', 0x8769 )
glget.addGLGetConstant( GL_ELEMENT_ARRAY_TYPE_ATI, (1,) )
GL_ELEMENT_ARRAY_POINTER_ATI = constant.Constant( 'GL_ELEMENT_ARRAY_POINTER_ATI', 0x876A )
glElementPointerATI = platform.createExtensionFunction( 
'glElementPointerATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,ctypes.c_void_p,),
doc='glElementPointerATI(GLenum(type), c_void_p(pointer)) -> None',
argNames=('type','pointer',),
deprecated=_DEPRECATED,
)

glDrawElementArrayATI = platform.createExtensionFunction( 
'glDrawElementArrayATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,),
doc='glDrawElementArrayATI(GLenum(mode), GLsizei(count)) -> None',
argNames=('mode','count',),
deprecated=_DEPRECATED,
)

glDrawRangeElementArrayATI = platform.createExtensionFunction( 
'glDrawRangeElementArrayATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLsizei,),
doc='glDrawRangeElementArrayATI(GLenum(mode), GLuint(start), GLuint(end), GLsizei(count)) -> None',
argNames=('mode','start','end','count',),
deprecated=_DEPRECATED,
)


def glInitElementArrayATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture_integer

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_integer'
_DEPRECATED = False
GL_RGBA32UI_EXT = constant.Constant( 'GL_RGBA32UI_EXT', 0x8D70 )
GL_RGB32UI_EXT = constant.Constant( 'GL_RGB32UI_EXT', 0x8D71 )
GL_ALPHA32UI_EXT = constant.Constant( 'GL_ALPHA32UI_EXT', 0x8D72 )
GL_INTENSITY32UI_EXT = constant.Constant( 'GL_INTENSITY32UI_EXT', 0x8D73 )
GL_LUMINANCE32UI_EXT = constant.Constant( 'GL_LUMINANCE32UI_EXT', 0x8D74 )
GL_LUMINANCE_ALPHA32UI_EXT = constant.Constant( 'GL_LUMINANCE_ALPHA32UI_EXT', 0x8D75 )
GL_RGBA16UI_EXT = constant.Constant( 'GL_RGBA16UI_EXT', 0x8D76 )
GL_RGB16UI_EXT = constant.Constant( 'GL_RGB16UI_EXT', 0x8D77 )
GL_ALPHA16UI_EXT = constant.Constant( 'GL_ALPHA16UI_EXT', 0x8D78 )
GL_INTENSITY16UI_EXT = constant.Constant( 'GL_INTENSITY16UI_EXT', 0x8D79 )
GL_LUMINANCE16UI_EXT = constant.Constant( 'GL_LUMINANCE16UI_EXT', 0x8D7A )
GL_LUMINANCE_ALPHA16UI_EXT = constant.Constant( 'GL_LUMINANCE_ALPHA16UI_EXT', 0x8D7B )
GL_RGBA8UI_EXT = constant.Constant( 'GL_RGBA8UI_EXT', 0x8D7C )
GL_RGB8UI_EXT = constant.Constant( 'GL_RGB8UI_EXT', 0x8D7D )
GL_ALPHA8UI_EXT = constant.Constant( 'GL_ALPHA8UI_EXT', 0x8D7E )
GL_INTENSITY8UI_EXT = constant.Constant( 'GL_INTENSITY8UI_EXT', 0x8D7F )
GL_LUMINANCE8UI_EXT = constant.Constant( 'GL_LUMINANCE8UI_EXT', 0x8D80 )
GL_LUMINANCE_ALPHA8UI_EXT = constant.Constant( 'GL_LUMINANCE_ALPHA8UI_EXT', 0x8D81 )
GL_RGBA32I_EXT = constant.Constant( 'GL_RGBA32I_EXT', 0x8D82 )
GL_RGB32I_EXT = constant.Constant( 'GL_RGB32I_EXT', 0x8D83 )
GL_ALPHA32I_EXT = constant.Constant( 'GL_ALPHA32I_EXT', 0x8D84 )
GL_INTENSITY32I_EXT = constant.Constant( 'GL_INTENSITY32I_EXT', 0x8D85 )
GL_LUMINANCE32I_EXT = constant.Constant( 'GL_LUMINANCE32I_EXT', 0x8D86 )
GL_LUMINANCE_ALPHA32I_EXT = constant.Constant( 'GL_LUMINANCE_ALPHA32I_EXT', 0x8D87 )
GL_RGBA16I_EXT = constant.Constant( 'GL_RGBA16I_EXT', 0x8D88 )
GL_RGB16I_EXT = constant.Constant( 'GL_RGB16I_EXT', 0x8D89 )
GL_ALPHA16I_EXT = constant.Constant( 'GL_ALPHA16I_EXT', 0x8D8A )
GL_INTENSITY16I_EXT = constant.Constant( 'GL_INTENSITY16I_EXT', 0x8D8B )
GL_LUMINANCE16I_EXT = constant.Constant( 'GL_LUMINANCE16I_EXT', 0x8D8C )
GL_LUMINANCE_ALPHA16I_EXT = constant.Constant( 'GL_LUMINANCE_ALPHA16I_EXT', 0x8D8D )
GL_RGBA8I_EXT = constant.Constant( 'GL_RGBA8I_EXT', 0x8D8E )
GL_RGB8I_EXT = constant.Constant( 'GL_RGB8I_EXT', 0x8D8F )
GL_ALPHA8I_EXT = constant.Constant( 'GL_ALPHA8I_EXT', 0x8D90 )
GL_INTENSITY8I_EXT = constant.Constant( 'GL_INTENSITY8I_EXT', 0x8D91 )
GL_LUMINANCE8I_EXT = constant.Constant( 'GL_LUMINANCE8I_EXT', 0x8D92 )
GL_LUMINANCE_ALPHA8I_EXT = constant.Constant( 'GL_LUMINANCE_ALPHA8I_EXT', 0x8D93 )
GL_RED_INTEGER_EXT = constant.Constant( 'GL_RED_INTEGER_EXT', 0x8D94 )
GL_GREEN_INTEGER_EXT = constant.Constant( 'GL_GREEN_INTEGER_EXT', 0x8D95 )
GL_BLUE_INTEGER_EXT = constant.Constant( 'GL_BLUE_INTEGER_EXT', 0x8D96 )
GL_ALPHA_INTEGER_EXT = constant.Constant( 'GL_ALPHA_INTEGER_EXT', 0x8D97 )
GL_RGB_INTEGER_EXT = constant.Constant( 'GL_RGB_INTEGER_EXT', 0x8D98 )
GL_RGBA_INTEGER_EXT = constant.Constant( 'GL_RGBA_INTEGER_EXT', 0x8D99 )
GL_BGR_INTEGER_EXT = constant.Constant( 'GL_BGR_INTEGER_EXT', 0x8D9A )
GL_BGRA_INTEGER_EXT = constant.Constant( 'GL_BGRA_INTEGER_EXT', 0x8D9B )
GL_LUMINANCE_INTEGER_EXT = constant.Constant( 'GL_LUMINANCE_INTEGER_EXT', 0x8D9C )
GL_LUMINANCE_ALPHA_INTEGER_EXT = constant.Constant( 'GL_LUMINANCE_ALPHA_INTEGER_EXT', 0x8D9D )
GL_RGBA_INTEGER_MODE_EXT = constant.Constant( 'GL_RGBA_INTEGER_MODE_EXT', 0x8D9E )
glTexParameterIivEXT = platform.createExtensionFunction( 
'glTexParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glTexParameterIivEXT(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glTexParameterIuivEXT = platform.createExtensionFunction( 
'glTexParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glTexParameterIuivEXT(GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTexParameterIivEXT = platform.createExtensionFunction( 
'glGetTexParameterIivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetTexParameterIivEXT(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTexParameterIuivEXT = platform.createExtensionFunction( 
'glGetTexParameterIuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glGetTexParameterIuivEXT(GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glClearColorIiEXT = platform.createExtensionFunction( 
'glClearColorIiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glClearColorIiEXT(GLint(red), GLint(green), GLint(blue), GLint(alpha)) -> None',
argNames=('red','green','blue','alpha',),
deprecated=_DEPRECATED,
)

glClearColorIuiEXT = platform.createExtensionFunction( 
'glClearColorIuiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glClearColorIuiEXT(GLuint(red), GLuint(green), GLuint(blue), GLuint(alpha)) -> None',
argNames=('red','green','blue','alpha',),
deprecated=_DEPRECATED,
)


def glInitTextureIntegerEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.fog_coord

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.fog_coord to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows specifying an explicit per-vertex fog
	coordinate to be used in fog computations, rather than using a
	fragment depth-based fog equation.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/fog_coord.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.fog_coord import *
### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.pixel_tiles

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_pixel_tiles'
_DEPRECATED = False
GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX = constant.Constant( 'GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX', 0x813E )
GL_PIXEL_TILE_CACHE_INCREMENT_SGIX = constant.Constant( 'GL_PIXEL_TILE_CACHE_INCREMENT_SGIX', 0x813F )
GL_PIXEL_TILE_WIDTH_SGIX = constant.Constant( 'GL_PIXEL_TILE_WIDTH_SGIX', 0x8140 )
GL_PIXEL_TILE_HEIGHT_SGIX = constant.Constant( 'GL_PIXEL_TILE_HEIGHT_SGIX', 0x8141 )
GL_PIXEL_TILE_GRID_WIDTH_SGIX = constant.Constant( 'GL_PIXEL_TILE_GRID_WIDTH_SGIX', 0x8142 )
GL_PIXEL_TILE_GRID_HEIGHT_SGIX = constant.Constant( 'GL_PIXEL_TILE_GRID_HEIGHT_SGIX', 0x8143 )
GL_PIXEL_TILE_GRID_DEPTH_SGIX = constant.Constant( 'GL_PIXEL_TILE_GRID_DEPTH_SGIX', 0x8144 )
GL_PIXEL_TILE_CACHE_SIZE_SGIX = constant.Constant( 'GL_PIXEL_TILE_CACHE_SIZE_SGIX', 0x8145 )


def glInitPixelTilesSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture_env_add

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture_env_add to provide a more 
Python-friendly API

Overview (from the spec)
	
	New texture environment function ADD is supported with the following 
	equation: 
	                    Cv = min(1, Cf + Ct)
	
	New function may be specified by calling TexEnv with ADD token.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_env_add.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.texture_env_add import *
### END AUTOGENERATED SECTION


'''OpenGL extension NV.texture_rectangle

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_texture_rectangle'
_DEPRECATED = False
GL_TEXTURE_RECTANGLE_NV = constant.Constant( 'GL_TEXTURE_RECTANGLE_NV', 0x84F5 )
glget.addGLGetConstant( GL_TEXTURE_RECTANGLE_NV, (1,) )
GL_TEXTURE_BINDING_RECTANGLE_NV = constant.Constant( 'GL_TEXTURE_BINDING_RECTANGLE_NV', 0x84F6 )
glget.addGLGetConstant( GL_TEXTURE_BINDING_RECTANGLE_NV, (1,) )
GL_PROXY_TEXTURE_RECTANGLE_NV = constant.Constant( 'GL_PROXY_TEXTURE_RECTANGLE_NV', 0x84F7 )
GL_MAX_RECTANGLE_TEXTURE_SIZE_NV = constant.Constant( 'GL_MAX_RECTANGLE_TEXTURE_SIZE_NV', 0x84F8 )
glget.addGLGetConstant( GL_MAX_RECTANGLE_TEXTURE_SIZE_NV, (1,) )


def glInitTextureRectangleNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.vertex_shader

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.vertex_shader to provide a more 
Python-friendly API

Overview (from the spec)
	
	EXT_vertex_shader adds a flexible way to change the per-vertex
	processing in the GL pipeline. It provides a method to replace
	the fixed vertex/normal transform and lighting with a user
	specified means of generating processed vertices, texture
	coordinates, color, and secondary color, along with a primitive's
	associated state.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/vertex_shader.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.vertex_shader import *
### END AUTOGENERATED SECTION


"""Array-size annotations for OpenGL.raw.GL

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw import GL as raw

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL import constants as GLconstants
GLvoid = GLconstants.GLvoid



glAreTexturesResident = arrays.setInputArraySizeType(
    raw.glAreTexturesResident,
    None, # XXX Could not determine size of argument textures for glAreTexturesResident arrays.GLuintArray
    arrays.GLuintArray, 
    'textures',
)

glBitmap = arrays.setInputArraySizeType(
    raw.glBitmap,
    None, # XXX Could not determine size of argument bitmap for glBitmap arrays.GLubyteArray
    arrays.GLubyteArray, 
    'bitmap',
)

glClipPlane = arrays.setInputArraySizeType(
    raw.glClipPlane,
    None, # XXX Could not determine size of argument equation for glClipPlane arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'equation',
)

glColor3bv = arrays.setInputArraySizeType(
    raw.glColor3bv,
    3,
    arrays.GLbyteArray,
    'v',
)

glColor3dv = arrays.setInputArraySizeType(
    raw.glColor3dv,
    3,
    arrays.GLdoubleArray,
    'v',
)

glColor3fv = arrays.setInputArraySizeType(
    raw.glColor3fv,
    3,
    arrays.GLfloatArray,
    'v',
)

glColor3iv = arrays.setInputArraySizeType(
    raw.glColor3iv,
    3,
    arrays.GLintArray,
    'v',
)

glColor3sv = arrays.setInputArraySizeType(
    raw.glColor3sv,
    3,
    arrays.GLshortArray,
    'v',
)

glColor3ubv = arrays.setInputArraySizeType(
    raw.glColor3ubv,
    3,
    arrays.GLubyteArray,
    'v',
)

glColor3uiv = arrays.setInputArraySizeType(
    raw.glColor3uiv,
    3,
    arrays.GLuintArray,
    'v',
)

glColor3usv = arrays.setInputArraySizeType(
    raw.glColor3usv,
    3,
    arrays.GLushortArray,
    'v',
)

glColor4bv = arrays.setInputArraySizeType(
    raw.glColor4bv,
    4,
    arrays.GLbyteArray,
    'v',
)

glColor4dv = arrays.setInputArraySizeType(
    raw.glColor4dv,
    4,
    arrays.GLdoubleArray,
    'v',
)

glColor4fv = arrays.setInputArraySizeType(
    raw.glColor4fv,
    4,
    arrays.GLfloatArray,
    'v',
)

glColor4iv = arrays.setInputArraySizeType(
    raw.glColor4iv,
    4,
    arrays.GLintArray,
    'v',
)

glColor4sv = arrays.setInputArraySizeType(
    raw.glColor4sv,
    4,
    arrays.GLshortArray,
    'v',
)

glColor4ubv = arrays.setInputArraySizeType(
    raw.glColor4ubv,
    4,
    arrays.GLubyteArray,
    'v',
)

glColor4uiv = arrays.setInputArraySizeType(
    raw.glColor4uiv,
    4,
    arrays.GLuintArray,
    'v',
)

glColor4usv = arrays.setInputArraySizeType(
    raw.glColor4usv,
    4,
    arrays.GLushortArray,
    'v',
)

glDeleteTextures = arrays.setInputArraySizeType(
    raw.glDeleteTextures,
    None, # XXX Could not determine size of argument textures for glDeleteTextures arrays.GLuintArray
    arrays.GLuintArray, 
    'textures',
)

glEvalCoord1dv = arrays.setInputArraySizeType(
    raw.glEvalCoord1dv,
    1,
    arrays.GLdoubleArray,
    'u',
)

glEvalCoord1fv = arrays.setInputArraySizeType(
    raw.glEvalCoord1fv,
    1,
    arrays.GLfloatArray,
    'u',
)

glEvalCoord2dv = arrays.setInputArraySizeType(
    raw.glEvalCoord2dv,
    2,
    arrays.GLdoubleArray,
    'u',
)

glEvalCoord2fv = arrays.setInputArraySizeType(
    raw.glEvalCoord2fv,
    2,
    arrays.GLfloatArray,
    'u',
)

glFeedbackBuffer = arrays.setInputArraySizeType(
    raw.glFeedbackBuffer,
    None, # XXX Could not determine size of argument buffer for glFeedbackBuffer arrays.GLfloatArray
    arrays.GLfloatArray, 
    'buffer',
)

glFogfv = arrays.setInputArraySizeType(
    raw.glFogfv,
    None, # XXX Could not determine size of argument params for glFogfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glFogiv = arrays.setInputArraySizeType(
    raw.glFogiv,
    None, # XXX Could not determine size of argument params for glFogiv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glGenTextures = arrays.setInputArraySizeType(
    raw.glGenTextures,
    None, # XXX Could not determine size of argument textures for glGenTextures arrays.GLuintArray
    arrays.GLuintArray, 
    'textures',
)

glGetClipPlane = arrays.setInputArraySizeType(
    raw.glGetClipPlane,
    None, # XXX Could not determine size of argument equation for glGetClipPlane arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'equation',
)

glGetDoublev = arrays.setInputArraySizeType(
    raw.glGetDoublev,
    None, # XXX Could not determine size of argument params for glGetDoublev arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'params',
)

glGetFloatv = arrays.setInputArraySizeType(
    raw.glGetFloatv,
    None, # XXX Could not determine size of argument params for glGetFloatv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glGetIntegerv = arrays.setInputArraySizeType(
    raw.glGetIntegerv,
    None, # XXX Could not determine size of argument params for glGetIntegerv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glGetLightfv = arrays.setInputArraySizeType(
    raw.glGetLightfv,
    None, # XXX Could not determine size of argument params for glGetLightfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glGetLightiv = arrays.setInputArraySizeType(
    raw.glGetLightiv,
    None, # XXX Could not determine size of argument params for glGetLightiv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glGetMapdv = arrays.setInputArraySizeType(
    raw.glGetMapdv,
    None, # XXX Could not determine size of argument v for glGetMapdv arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'v',
)

glGetMapfv = arrays.setInputArraySizeType(
    raw.glGetMapfv,
    None, # XXX Could not determine size of argument v for glGetMapfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'v',
)

glGetMapiv = arrays.setInputArraySizeType(
    raw.glGetMapiv,
    None, # XXX Could not determine size of argument v for glGetMapiv arrays.GLintArray
    arrays.GLintArray, 
    'v',
)

glGetMaterialfv = arrays.setInputArraySizeType(
    raw.glGetMaterialfv,
    None, # XXX Could not determine size of argument params for glGetMaterialfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glGetMaterialiv = arrays.setInputArraySizeType(
    raw.glGetMaterialiv,
    None, # XXX Could not determine size of argument params for glGetMaterialiv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glGetPixelMapfv = arrays.setInputArraySizeType(
    raw.glGetPixelMapfv,
    None, # XXX Could not determine size of argument values for glGetPixelMapfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'values',
)

glGetPixelMapuiv = arrays.setInputArraySizeType(
    raw.glGetPixelMapuiv,
    None, # XXX Could not determine size of argument values for glGetPixelMapuiv arrays.GLuintArray
    arrays.GLuintArray, 
    'values',
)

glGetPixelMapusv = arrays.setInputArraySizeType(
    raw.glGetPixelMapusv,
    None, # XXX Could not determine size of argument values for glGetPixelMapusv arrays.GLushortArray
    arrays.GLushortArray, 
    'values',
)

glGetPolygonStipple = arrays.setInputArraySizeType(
    raw.glGetPolygonStipple,
    None, # XXX Could not determine size of argument mask for glGetPolygonStipple arrays.GLubyteArray
    arrays.GLubyteArray, 
    'mask',
)

glGetTexEnvfv = arrays.setInputArraySizeType(
    raw.glGetTexEnvfv,
    None, # XXX Could not determine size of argument params for glGetTexEnvfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glGetTexEnviv = arrays.setInputArraySizeType(
    raw.glGetTexEnviv,
    None, # XXX Could not determine size of argument params for glGetTexEnviv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glGetTexGendv = arrays.setInputArraySizeType(
    raw.glGetTexGendv,
    None, # XXX Could not determine size of argument params for glGetTexGendv arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'params',
)

glGetTexGenfv = arrays.setInputArraySizeType(
    raw.glGetTexGenfv,
    None, # XXX Could not determine size of argument params for glGetTexGenfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glGetTexGeniv = arrays.setInputArraySizeType(
    raw.glGetTexGeniv,
    None, # XXX Could not determine size of argument params for glGetTexGeniv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glGetTexLevelParameterfv = arrays.setInputArraySizeType(
    raw.glGetTexLevelParameterfv,
    None, # XXX Could not determine size of argument params for glGetTexLevelParameterfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glGetTexLevelParameteriv = arrays.setInputArraySizeType(
    raw.glGetTexLevelParameteriv,
    None, # XXX Could not determine size of argument params for glGetTexLevelParameteriv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glGetTexParameterfv = arrays.setInputArraySizeType(
    raw.glGetTexParameterfv,
    None, # XXX Could not determine size of argument params for glGetTexParameterfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glGetTexParameteriv = arrays.setInputArraySizeType(
    raw.glGetTexParameteriv,
    None, # XXX Could not determine size of argument params for glGetTexParameteriv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glIndexdv = arrays.setInputArraySizeType(
    raw.glIndexdv,
    None, # XXX Could not determine size of argument c for glIndexdv arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'c',
)

glIndexfv = arrays.setInputArraySizeType(
    raw.glIndexfv,
    None, # XXX Could not determine size of argument c for glIndexfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'c',
)

glIndexiv = arrays.setInputArraySizeType(
    raw.glIndexiv,
    None, # XXX Could not determine size of argument c for glIndexiv arrays.GLintArray
    arrays.GLintArray, 
    'c',
)

glIndexsv = arrays.setInputArraySizeType(
    raw.glIndexsv,
    None, # XXX Could not determine size of argument c for glIndexsv arrays.GLshortArray
    arrays.GLshortArray, 
    'c',
)

glIndexubv = arrays.setInputArraySizeType(
    raw.glIndexubv,
    None, # XXX Could not determine size of argument c for glIndexubv arrays.GLubyteArray
    arrays.GLubyteArray, 
    'c',
)

glLightModelfv = arrays.setInputArraySizeType(
    raw.glLightModelfv,
    None, # XXX Could not determine size of argument params for glLightModelfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glLightModeliv = arrays.setInputArraySizeType(
    raw.glLightModeliv,
    None, # XXX Could not determine size of argument params for glLightModeliv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glLightfv = arrays.setInputArraySizeType(
    raw.glLightfv,
    None, # XXX Could not determine size of argument params for glLightfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glLightiv = arrays.setInputArraySizeType(
    raw.glLightiv,
    None, # XXX Could not determine size of argument params for glLightiv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glLoadMatrixd = arrays.setInputArraySizeType(
    raw.glLoadMatrixd,
    16,
    arrays.GLdoubleArray,
    'm',
)

glLoadMatrixf = arrays.setInputArraySizeType(
    raw.glLoadMatrixf,
    16,
    arrays.GLfloatArray,
    'm',
)

glMap1d = arrays.setInputArraySizeType(
    raw.glMap1d,
    None, # XXX Could not determine size of argument points for glMap1d arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'points',
)

glMap1f = arrays.setInputArraySizeType(
    raw.glMap1f,
    None, # XXX Could not determine size of argument points for glMap1f arrays.GLfloatArray
    arrays.GLfloatArray, 
    'points',
)

glMap2d = arrays.setInputArraySizeType(
    raw.glMap2d,
    None, # XXX Could not determine size of argument points for glMap2d arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'points',
)

glMap2f = arrays.setInputArraySizeType(
    raw.glMap2f,
    None, # XXX Could not determine size of argument points for glMap2f arrays.GLfloatArray
    arrays.GLfloatArray, 
    'points',
)

glMaterialfv = arrays.setInputArraySizeType(
    raw.glMaterialfv,
    None, # XXX Could not determine size of argument params for glMaterialfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glMaterialiv = arrays.setInputArraySizeType(
    raw.glMaterialiv,
    None, # XXX Could not determine size of argument params for glMaterialiv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glMultMatrixd = arrays.setInputArraySizeType(
    raw.glMultMatrixd,
    16,
    arrays.GLdoubleArray,
    'm',
)

glMultMatrixf = arrays.setInputArraySizeType(
    raw.glMultMatrixf,
    16,
    arrays.GLfloatArray,
    'm',
)

glNormal3bv = arrays.setInputArraySizeType(
    raw.glNormal3bv,
    3,
    arrays.GLbyteArray,
    'v',
)

glNormal3dv = arrays.setInputArraySizeType(
    raw.glNormal3dv,
    3,
    arrays.GLdoubleArray,
    'v',
)

glNormal3fv = arrays.setInputArraySizeType(
    raw.glNormal3fv,
    3,
    arrays.GLfloatArray,
    'v',
)

glNormal3iv = arrays.setInputArraySizeType(
    raw.glNormal3iv,
    3,
    arrays.GLintArray,
    'v',
)

glNormal3sv = arrays.setInputArraySizeType(
    raw.glNormal3sv,
    3,
    arrays.GLshortArray,
    'v',
)

glPixelMapfv = arrays.setInputArraySizeType(
    raw.glPixelMapfv,
    None, # XXX Could not determine size of argument values for glPixelMapfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'values',
)

glPixelMapuiv = arrays.setInputArraySizeType(
    raw.glPixelMapuiv,
    None, # XXX Could not determine size of argument values for glPixelMapuiv arrays.GLuintArray
    arrays.GLuintArray, 
    'values',
)

glPixelMapusv = arrays.setInputArraySizeType(
    raw.glPixelMapusv,
    None, # XXX Could not determine size of argument values for glPixelMapusv arrays.GLushortArray
    arrays.GLushortArray, 
    'values',
)

glPolygonStipple = arrays.setInputArraySizeType(
    raw.glPolygonStipple,
    None, # XXX Could not determine size of argument mask for glPolygonStipple arrays.GLubyteArray
    arrays.GLubyteArray, 
    'mask',
)

glPrioritizeTextures = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.glPrioritizeTextures,
        None, # XXX Could not determine size of argument textures for glPrioritizeTextures arrays.GLuintArray
        arrays.GLuintArray, 
        'textures',
    ),
    None, # XXX Could not determine size of argument priorities for glPrioritizeTextures arrays.GLclampfArray
    arrays.GLclampfArray, 
    'priorities',
)

glRasterPos2dv = arrays.setInputArraySizeType(
    raw.glRasterPos2dv,
    2,
    arrays.GLdoubleArray,
    'v',
)

glRasterPos2fv = arrays.setInputArraySizeType(
    raw.glRasterPos2fv,
    2,
    arrays.GLfloatArray,
    'v',
)

glRasterPos2iv = arrays.setInputArraySizeType(
    raw.glRasterPos2iv,
    2,
    arrays.GLintArray,
    'v',
)

glRasterPos2sv = arrays.setInputArraySizeType(
    raw.glRasterPos2sv,
    2,
    arrays.GLshortArray,
    'v',
)

glRasterPos3dv = arrays.setInputArraySizeType(
    raw.glRasterPos3dv,
    3,
    arrays.GLdoubleArray,
    'v',
)

glRasterPos3fv = arrays.setInputArraySizeType(
    raw.glRasterPos3fv,
    3,
    arrays.GLfloatArray,
    'v',
)

glRasterPos3iv = arrays.setInputArraySizeType(
    raw.glRasterPos3iv,
    3,
    arrays.GLintArray,
    'v',
)

glRasterPos3sv = arrays.setInputArraySizeType(
    raw.glRasterPos3sv,
    3,
    arrays.GLshortArray,
    'v',
)

glRasterPos4dv = arrays.setInputArraySizeType(
    raw.glRasterPos4dv,
    4,
    arrays.GLdoubleArray,
    'v',
)

glRasterPos4fv = arrays.setInputArraySizeType(
    raw.glRasterPos4fv,
    4,
    arrays.GLfloatArray,
    'v',
)

glRasterPos4iv = arrays.setInputArraySizeType(
    raw.glRasterPos4iv,
    4,
    arrays.GLintArray,
    'v',
)

glRasterPos4sv = arrays.setInputArraySizeType(
    raw.glRasterPos4sv,
    4,
    arrays.GLshortArray,
    'v',
)

glRectdv = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.glRectdv,
        None, # XXX Could not determine size of argument v1 for glRectdv arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'v1',
    ),
    None, # XXX Could not determine size of argument v2 for glRectdv arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'v2',
)

glRectfv = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.glRectfv,
        None, # XXX Could not determine size of argument v1 for glRectfv arrays.GLfloatArray
        arrays.GLfloatArray, 
        'v1',
    ),
    None, # XXX Could not determine size of argument v2 for glRectfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'v2',
)

glRectiv = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.glRectiv,
        None, # XXX Could not determine size of argument v1 for glRectiv arrays.GLintArray
        arrays.GLintArray, 
        'v1',
    ),
    None, # XXX Could not determine size of argument v2 for glRectiv arrays.GLintArray
    arrays.GLintArray, 
    'v2',
)

glRectsv = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.glRectsv,
        None, # XXX Could not determine size of argument v1 for glRectsv arrays.GLshortArray
        arrays.GLshortArray, 
        'v1',
    ),
    None, # XXX Could not determine size of argument v2 for glRectsv arrays.GLshortArray
    arrays.GLshortArray, 
    'v2',
)

glSelectBuffer = arrays.setInputArraySizeType(
    raw.glSelectBuffer,
    None, # XXX Could not determine size of argument buffer for glSelectBuffer arrays.GLuintArray
    arrays.GLuintArray, 
    'buffer',
)

glTexCoord1dv = arrays.setInputArraySizeType(
    raw.glTexCoord1dv,
    1,
    arrays.GLdoubleArray,
    'v',
)

glTexCoord1fv = arrays.setInputArraySizeType(
    raw.glTexCoord1fv,
    1,
    arrays.GLfloatArray,
    'v',
)

glTexCoord1iv = arrays.setInputArraySizeType(
    raw.glTexCoord1iv,
    1,
    arrays.GLintArray,
    'v',
)

glTexCoord1sv = arrays.setInputArraySizeType(
    raw.glTexCoord1sv,
    1,
    arrays.GLshortArray,
    'v',
)

glTexCoord2dv = arrays.setInputArraySizeType(
    raw.glTexCoord2dv,
    2,
    arrays.GLdoubleArray,
    'v',
)

glTexCoord2fv = arrays.setInputArraySizeType(
    raw.glTexCoord2fv,
    2,
    arrays.GLfloatArray,
    'v',
)

glTexCoord2iv = arrays.setInputArraySizeType(
    raw.glTexCoord2iv,
    2,
    arrays.GLintArray,
    'v',
)

glTexCoord2sv = arrays.setInputArraySizeType(
    raw.glTexCoord2sv,
    2,
    arrays.GLshortArray,
    'v',
)

glTexCoord3dv = arrays.setInputArraySizeType(
    raw.glTexCoord3dv,
    3,
    arrays.GLdoubleArray,
    'v',
)

glTexCoord3fv = arrays.setInputArraySizeType(
    raw.glTexCoord3fv,
    3,
    arrays.GLfloatArray,
    'v',
)

glTexCoord3iv = arrays.setInputArraySizeType(
    raw.glTexCoord3iv,
    3,
    arrays.GLintArray,
    'v',
)

glTexCoord3sv = arrays.setInputArraySizeType(
    raw.glTexCoord3sv,
    3,
    arrays.GLshortArray,
    'v',
)

glTexCoord4dv = arrays.setInputArraySizeType(
    raw.glTexCoord4dv,
    4,
    arrays.GLdoubleArray,
    'v',
)

glTexCoord4fv = arrays.setInputArraySizeType(
    raw.glTexCoord4fv,
    4,
    arrays.GLfloatArray,
    'v',
)

glTexCoord4iv = arrays.setInputArraySizeType(
    raw.glTexCoord4iv,
    4,
    arrays.GLintArray,
    'v',
)

glTexCoord4sv = arrays.setInputArraySizeType(
    raw.glTexCoord4sv,
    4,
    arrays.GLshortArray,
    'v',
)

glTexEnvfv = arrays.setInputArraySizeType(
    raw.glTexEnvfv,
    None, # XXX Could not determine size of argument params for glTexEnvfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glTexEnviv = arrays.setInputArraySizeType(
    raw.glTexEnviv,
    None, # XXX Could not determine size of argument params for glTexEnviv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glTexGendv = arrays.setInputArraySizeType(
    raw.glTexGendv,
    None, # XXX Could not determine size of argument params for glTexGendv arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'params',
)

glTexGenfv = arrays.setInputArraySizeType(
    raw.glTexGenfv,
    None, # XXX Could not determine size of argument params for glTexGenfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glTexGeniv = arrays.setInputArraySizeType(
    raw.glTexGeniv,
    None, # XXX Could not determine size of argument params for glTexGeniv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glTexParameterfv = arrays.setInputArraySizeType(
    raw.glTexParameterfv,
    None, # XXX Could not determine size of argument params for glTexParameterfv arrays.GLfloatArray
    arrays.GLfloatArray, 
    'params',
)

glTexParameteriv = arrays.setInputArraySizeType(
    raw.glTexParameteriv,
    None, # XXX Could not determine size of argument params for glTexParameteriv arrays.GLintArray
    arrays.GLintArray, 
    'params',
)

glVertex2dv = arrays.setInputArraySizeType(
    raw.glVertex2dv,
    2,
    arrays.GLdoubleArray,
    'v',
)

glVertex2fv = arrays.setInputArraySizeType(
    raw.glVertex2fv,
    2,
    arrays.GLfloatArray,
    'v',
)

glVertex2iv = arrays.setInputArraySizeType(
    raw.glVertex2iv,
    2,
    arrays.GLintArray,
    'v',
)

glVertex2sv = arrays.setInputArraySizeType(
    raw.glVertex2sv,
    2,
    arrays.GLshortArray,
    'v',
)

glVertex3dv = arrays.setInputArraySizeType(
    raw.glVertex3dv,
    3,
    arrays.GLdoubleArray,
    'v',
)

glVertex3fv = arrays.setInputArraySizeType(
    raw.glVertex3fv,
    3,
    arrays.GLfloatArray,
    'v',
)

glVertex3iv = arrays.setInputArraySizeType(
    raw.glVertex3iv,
    3,
    arrays.GLintArray,
    'v',
)

glVertex3sv = arrays.setInputArraySizeType(
    raw.glVertex3sv,
    3,
    arrays.GLshortArray,
    'v',
)

glVertex4dv = arrays.setInputArraySizeType(
    raw.glVertex4dv,
    4,
    arrays.GLdoubleArray,
    'v',
)

glVertex4fv = arrays.setInputArraySizeType(
    raw.glVertex4fv,
    4,
    arrays.GLfloatArray,
    'v',
)

glVertex4iv = arrays.setInputArraySizeType(
    raw.glVertex4iv,
    4,
    arrays.GLintArray,
    'v',
)

glVertex4sv = arrays.setInputArraySizeType(
    raw.glVertex4sv,
    4,
    arrays.GLshortArray,
    'v',
)

__all__ = [
    'glAreTexturesResident',
    'glBitmap',
    'glClipPlane',
    'glColor3bv',
    'glColor3dv',
    'glColor3fv',
    'glColor3iv',
    'glColor3sv',
    'glColor3ubv',
    'glColor3uiv',
    'glColor3usv',
    'glColor4bv',
    'glColor4dv',
    'glColor4fv',
    'glColor4iv',
    'glColor4sv',
    'glColor4ubv',
    'glColor4uiv',
    'glColor4usv',
    'glDeleteTextures',
    'glEvalCoord1dv',
    'glEvalCoord1fv',
    'glEvalCoord2dv',
    'glEvalCoord2fv',
    'glFeedbackBuffer',
    'glFogfv',
    'glFogiv',
    'glGenTextures',
    'glGetClipPlane',
    'glGetDoublev',
    'glGetFloatv',
    'glGetIntegerv',
    'glGetLightfv',
    'glGetLightiv',
    'glGetMapdv',
    'glGetMapfv',
    'glGetMapiv',
    'glGetMaterialfv',
    'glGetMaterialiv',
    'glGetPixelMapfv',
    'glGetPixelMapuiv',
    'glGetPixelMapusv',
    'glGetPolygonStipple',
    'glGetTexEnvfv',
    'glGetTexEnviv',
    'glGetTexGendv',
    'glGetTexGenfv',
    'glGetTexGeniv',
    'glGetTexLevelParameterfv',
    'glGetTexLevelParameteriv',
    'glGetTexParameterfv',
    'glGetTexParameteriv',
    'glIndexdv',
    'glIndexfv',
    'glIndexiv',
    'glIndexsv',
    'glIndexubv',
    'glLightModelfv',
    'glLightModeliv',
    'glLightfv',
    'glLightiv',
    'glLoadMatrixd',
    'glLoadMatrixf',
    'glMap1d',
    'glMap1f',
    'glMap2d',
    'glMap2f',
    'glMaterialfv',
    'glMaterialiv',
    'glMultMatrixd',
    'glMultMatrixf',
    'glNormal3bv',
    'glNormal3dv',
    'glNormal3fv',
    'glNormal3iv',
    'glNormal3sv',
    'glPixelMapfv',
    'glPixelMapuiv',
    'glPixelMapusv',
    'glPolygonStipple',
    'glPrioritizeTextures',
    'glRasterPos2dv',
    'glRasterPos2fv',
    'glRasterPos2iv',
    'glRasterPos2sv',
    'glRasterPos3dv',
    'glRasterPos3fv',
    'glRasterPos3iv',
    'glRasterPos3sv',
    'glRasterPos4dv',
    'glRasterPos4fv',
    'glRasterPos4iv',
    'glRasterPos4sv',
    'glRectdv',
    'glRectfv',
    'glRectiv',
    'glRectsv',
    'glSelectBuffer',
    'glTexCoord1dv',
    'glTexCoord1fv',
    'glTexCoord1iv',
    'glTexCoord1sv',
    'glTexCoord2dv',
    'glTexCoord2fv',
    'glTexCoord2iv',
    'glTexCoord2sv',
    'glTexCoord3dv',
    'glTexCoord3fv',
    'glTexCoord3iv',
    'glTexCoord3sv',
    'glTexCoord4dv',
    'glTexCoord4fv',
    'glTexCoord4iv',
    'glTexCoord4sv',
    'glTexEnvfv',
    'glTexEnviv',
    'glTexGendv',
    'glTexGenfv',
    'glTexGeniv',
    'glTexParameterfv',
    'glTexParameteriv',
    'glVertex2dv',
    'glVertex2fv',
    'glVertex2iv',
    'glVertex2sv',
    'glVertex3dv',
    'glVertex3fv',
    'glVertex3iv',
    'glVertex3sv',
    'glVertex4dv',
    'glVertex4fv',
    'glVertex4iv',
    'glVertex4sv'
]



'''OpenGL extension ARB.framebuffer_object_DEPRECATED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_framebuffer_object'
_DEPRECATED = True
GL_INDEX = constant.Constant( 'GL_INDEX', 0x8222 )
GL_TEXTURE_LUMINANCE_TYPE = constant.Constant( 'GL_TEXTURE_LUMINANCE_TYPE', 0x8C14 )
GL_TEXTURE_INTENSITY_TYPE = constant.Constant( 'GL_TEXTURE_INTENSITY_TYPE', 0x8C15 )


def glInitFramebufferObjectDeprecatedARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""Fix missing-API problems in logging module (circa Python 2.3)

Adds constants to the log objects.
Adds getException(err) to log objects to retrieve 
formatted exception or err if traceback not available.
"""
try:
    from cStringIO import StringIO
except ImportError, err:
    from StringIO import StringIO
import traceback, logging

getLog = logging.getLogger
from OpenGL import ERROR_LOGGING, FULL_LOGGING

if not hasattr( traceback, 'format_exc' ):
    # Python 2.3 and below... do we care any more?
    def format_exc( limit ):
        file = StringIO()
        try:
            traceback.print_exc( limit=10, file = file )
            exception = file.getvalue()
        finally:
            file.close()
        return exception
else:
    format_exc = traceback.format_exc

def getException(error):
    """Get formatted traceback from exception"""
    try:
        return format_exc( limit=10 )
    except Exception, err:
        return str( error )

logging.Logger.getException = staticmethod( getException )
logging.Logger.err = logging.Logger.error
logging.Logger.DEBUG = logging.DEBUG 
logging.Logger.WARN = logging.WARN 
logging.Logger.INFO = logging.INFO 
logging.Logger.ERR = logging.Logger.ERROR = logging.ERROR

if FULL_LOGGING:
    getLog( 'OpenGL.calltrace' ).setLevel( logging.INFO )

class _LoggedFunction( object ):
    """Proxy that overrides __call__ to log arguments"""
    def __init__( self, base, log ):
        self.__dict__[''] = base 
        self.__dict__['log'] = log
    def __setattr__( self, key, value ):
        if key != '':
            setattr( self.__dict__[''], key, value )
        else:
            self.__dict__[''] = value 
    def __getattr__( self, key ):
        if key == '':
            return self.__dict__['']
        else:
            return getattr( self.__dict__[''], key )
class _FullLoggedFunction( _LoggedFunction ):
    """Fully-logged function wrapper (logs all call params to OpenGL.calltrace)"""
    _callTrace = getLog( 'OpenGL.calltrace' )
    def __call__( self, *args, **named ):
        argRepr = []
        function = getattr( self, '' )
        for arg in args:
            argRepr.append( repr(arg) )
        for key,value in named.items():
            argRepr.append( '%s = %s'%( key,repr(value)) )
        argRepr = ",".join( argRepr )
        self._callTrace.info( '%s( %s )', function.__name__, argRepr )
        try:
            return function( *args, **named )
        except Exception, err:
            self.log.warn(
                """Failure on %s: %s""", function.__name__, self.log.getException( err )
            )
            raise
class _ErrorLoggedFunction ( _LoggedFunction ):
    """On-error-logged function wrapper"""
    def __call__( self, *args, **named ):
        function = getattr( self, '' )
        try:
            return function( *args, **named )
        except Exception, err:
            self.log.warn(
                """Failure on %s: %s""", function.__name__, self.log.getException( err )
            )
            raise
    

def logOnFail( function, log ):
    """Produce possible log-wrapped version of function

    function -- callable object to be wrapped
    log -- the log to which to log information
    
    Uses ERROR_LOGGING and FULL_LOGGING
    to determine whether/how to wrap the function.
    """
    if ERROR_LOGGING or FULL_LOGGING:
        if FULL_LOGGING:
            loggedFunction = _FullLoggedFunction( function, log )
        else:
            loggedFunction = _ErrorLoggedFunction( function, log )
        return loggedFunction
    else:
        return function


'''OpenGL extension ARB.transpose_matrix

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_transpose_matrix'
_DEPRECATED = False
GL_TRANSPOSE_MODELVIEW_MATRIX_ARB = constant.Constant( 'GL_TRANSPOSE_MODELVIEW_MATRIX_ARB', 0x84E3 )
glget.addGLGetConstant( GL_TRANSPOSE_MODELVIEW_MATRIX_ARB, (4,4) )
GL_TRANSPOSE_PROJECTION_MATRIX_ARB = constant.Constant( 'GL_TRANSPOSE_PROJECTION_MATRIX_ARB', 0x84E4 )
glget.addGLGetConstant( GL_TRANSPOSE_PROJECTION_MATRIX_ARB, (4,4) )
GL_TRANSPOSE_TEXTURE_MATRIX_ARB = constant.Constant( 'GL_TRANSPOSE_TEXTURE_MATRIX_ARB', 0x84E5 )
glget.addGLGetConstant( GL_TRANSPOSE_TEXTURE_MATRIX_ARB, (4,4) )
GL_TRANSPOSE_COLOR_MATRIX_ARB = constant.Constant( 'GL_TRANSPOSE_COLOR_MATRIX_ARB', 0x84E6 )
glget.addGLGetConstant( GL_TRANSPOSE_COLOR_MATRIX_ARB, (4,4) )
glLoadTransposeMatrixfARB = platform.createExtensionFunction( 
'glLoadTransposeMatrixfARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glLoadTransposeMatrixfARB(GLfloatArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)

glLoadTransposeMatrixdARB = platform.createExtensionFunction( 
'glLoadTransposeMatrixdARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glLoadTransposeMatrixdARB(GLdoubleArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)

glMultTransposeMatrixfARB = platform.createExtensionFunction( 
'glMultTransposeMatrixfARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glMultTransposeMatrixfARB(GLfloatArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)

glMultTransposeMatrixdARB = platform.createExtensionFunction( 
'glMultTransposeMatrixdARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glMultTransposeMatrixdARB(GLdoubleArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)


def glInitTransposeMatrixARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SUN.convolution_border_modes

This module customises the behaviour of the 
OpenGL.raw.GL.SUN.convolution_border_modes to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides an additional border mode for the
	EXT_convolution extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SUN/convolution_border_modes.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.SUN.convolution_border_modes import *
### END AUTOGENERATED SECTION


'''OpenGL extension ATI.draw_buffers

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_draw_buffers'
_DEPRECATED = False
GL_MAX_DRAW_BUFFERS_ATI = constant.Constant( 'GL_MAX_DRAW_BUFFERS_ATI', 0x8824 )
glget.addGLGetConstant( GL_MAX_DRAW_BUFFERS_ATI, (1,) )
GL_DRAW_BUFFER0_ATI = constant.Constant( 'GL_DRAW_BUFFER0_ATI', 0x8825 )
glget.addGLGetConstant( GL_DRAW_BUFFER0_ATI, (1,) )
GL_DRAW_BUFFER1_ATI = constant.Constant( 'GL_DRAW_BUFFER1_ATI', 0x8826 )
glget.addGLGetConstant( GL_DRAW_BUFFER1_ATI, (1,) )
GL_DRAW_BUFFER2_ATI = constant.Constant( 'GL_DRAW_BUFFER2_ATI', 0x8827 )
glget.addGLGetConstant( GL_DRAW_BUFFER2_ATI, (1,) )
GL_DRAW_BUFFER3_ATI = constant.Constant( 'GL_DRAW_BUFFER3_ATI', 0x8828 )
glget.addGLGetConstant( GL_DRAW_BUFFER3_ATI, (1,) )
GL_DRAW_BUFFER4_ATI = constant.Constant( 'GL_DRAW_BUFFER4_ATI', 0x8829 )
glget.addGLGetConstant( GL_DRAW_BUFFER4_ATI, (1,) )
GL_DRAW_BUFFER5_ATI = constant.Constant( 'GL_DRAW_BUFFER5_ATI', 0x882A )
glget.addGLGetConstant( GL_DRAW_BUFFER5_ATI, (1,) )
GL_DRAW_BUFFER6_ATI = constant.Constant( 'GL_DRAW_BUFFER6_ATI', 0x882B )
glget.addGLGetConstant( GL_DRAW_BUFFER6_ATI, (1,) )
GL_DRAW_BUFFER7_ATI = constant.Constant( 'GL_DRAW_BUFFER7_ATI', 0x882C )
glget.addGLGetConstant( GL_DRAW_BUFFER7_ATI, (1,) )
GL_DRAW_BUFFER8_ATI = constant.Constant( 'GL_DRAW_BUFFER8_ATI', 0x882D )
glget.addGLGetConstant( GL_DRAW_BUFFER8_ATI, (1,) )
GL_DRAW_BUFFER9_ATI = constant.Constant( 'GL_DRAW_BUFFER9_ATI', 0x882E )
glget.addGLGetConstant( GL_DRAW_BUFFER9_ATI, (1,) )
GL_DRAW_BUFFER10_ATI = constant.Constant( 'GL_DRAW_BUFFER10_ATI', 0x882F )
glget.addGLGetConstant( GL_DRAW_BUFFER10_ATI, (1,) )
GL_DRAW_BUFFER11_ATI = constant.Constant( 'GL_DRAW_BUFFER11_ATI', 0x8830 )
glget.addGLGetConstant( GL_DRAW_BUFFER11_ATI, (1,) )
GL_DRAW_BUFFER12_ATI = constant.Constant( 'GL_DRAW_BUFFER12_ATI', 0x8831 )
glget.addGLGetConstant( GL_DRAW_BUFFER12_ATI, (1,) )
GL_DRAW_BUFFER13_ATI = constant.Constant( 'GL_DRAW_BUFFER13_ATI', 0x8832 )
glget.addGLGetConstant( GL_DRAW_BUFFER13_ATI, (1,) )
GL_DRAW_BUFFER14_ATI = constant.Constant( 'GL_DRAW_BUFFER14_ATI', 0x8833 )
glget.addGLGetConstant( GL_DRAW_BUFFER14_ATI, (1,) )
GL_DRAW_BUFFER15_ATI = constant.Constant( 'GL_DRAW_BUFFER15_ATI', 0x8834 )
glget.addGLGetConstant( GL_DRAW_BUFFER15_ATI, (1,) )
glDrawBuffersATI = platform.createExtensionFunction( 
'glDrawBuffersATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDrawBuffersATI(GLsizei(n), GLuintArray(bufs)) -> None',
argNames=('n','bufs',),
deprecated=_DEPRECATED,
)


def glInitDrawBuffersATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SUN.slice_accum

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SUN_slice_accum'
_DEPRECATED = False
GL_SLICE_ACCUM_SUN = constant.Constant( 'GL_SLICE_ACCUM_SUN', 0x85CC )


def glInitSliceAccumSUN():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""Windows-specific platform features"""
import ctypes
from OpenGL.platform import ctypesloader, baseplatform

class Win32Platform( baseplatform.BasePlatform ):
    """Win32-specific platform implementation"""

    GLUT_GUARD_CALLBACKS = True
    try:
        GL = OpenGL = ctypesloader.loadLibrary( 
            ctypes.windll, 'opengl32', mode = ctypes.RTLD_GLOBAL 
        )
    except OSError, err:
        raise ImportError("Unable to load OpenGL library", *err.args)
        
    try:
        GLU = ctypesloader.loadLibrary( 
            ctypes.windll, 'glu32', mode = ctypes.RTLD_GLOBAL 
        )
    except OSError, err:
        GLU = None
    
    GLUT = None 
    for possible in ('glut32','freeglut32','freeglut'):
        # load first-up of the possible names...
        try:
            GLUT = ctypesloader.loadLibrary( 
                ctypes.windll, possible, mode = ctypes.RTLD_GLOBAL 
            )
        except WindowsError, err:
            GLUT = None
        else:
            break
    del possible 
    
    GLE = None
    for libName in ('gle32','opengle32'):
        try:
            GLE = ctypesloader.loadLibrary( ctypes.cdll, libName )
            GLE.FunctionType = ctypes.CFUNCTYPE
        except WindowsError, err:
            pass
        else:
            break
    
    DEFAULT_FUNCTION_TYPE = staticmethod( ctypes.WINFUNCTYPE )
    # Win32 GLUT uses different types for callbacks and functions...
    GLUT_CALLBACK_TYPE = staticmethod( ctypes.CFUNCTYPE )
    WGL = ctypes.windll.gdi32
    getExtensionProcedure = staticmethod( OpenGL.wglGetProcAddress )

    GLUT_FONT_CONSTANTS = {
        'GLUT_STROKE_ROMAN': ctypes.c_void_p( 0),
        'GLUT_STROKE_MONO_ROMAN': ctypes.c_void_p( 1),
        'GLUT_BITMAP_9_BY_15': ctypes.c_void_p( 2),
        'GLUT_BITMAP_8_BY_13': ctypes.c_void_p( 3),
        'GLUT_BITMAP_TIMES_ROMAN_10': ctypes.c_void_p( 4),
        'GLUT_BITMAP_TIMES_ROMAN_24': ctypes.c_void_p( 5),
        'GLUT_BITMAP_HELVETICA_10': ctypes.c_void_p( 6),
        'GLUT_BITMAP_HELVETICA_12': ctypes.c_void_p( 7),
        'GLUT_BITMAP_HELVETICA_18': ctypes.c_void_p( 8),
    }


    def getGLUTFontPointer( self,constant ):
        """Platform specific function to retrieve a GLUT font pointer
        
        GLUTAPI void *glutBitmap9By15;
        #define GLUT_BITMAP_9_BY_15		(&glutBitmap9By15)
        
        Key here is that we want the addressof the pointer in the DLL,
        not the pointer in the DLL.  That is, our pointer is to the 
        pointer defined in the DLL, we don't want the *value* stored in
        that pointer.
        """
        return self.GLUT_FONT_CONSTANTS[ constant ]

    GetCurrentContext = CurrentContextIsValid = staticmethod(
        GL.wglGetCurrentContext
    )


    def safeGetError( self ):
        """Provide context-not-present-safe error-checking
        
        Under OS-X an attempt to retrieve error without checking 
        context will bus-error.  Likely Windows will see the same.
        This function checks for a valid context before running 
        glGetError
        
        Note:
            This is a likely candidate for rewriting in C, as it
            is called for every almost function in the system!
        """
        if self.CurrentContextIsValid():
            return glGetError()
        return None

glGetError = Win32Platform.OpenGL.glGetError



'''OpenGL extension OML.resample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_OML_resample'
_DEPRECATED = False
GL_PACK_RESAMPLE_OML = constant.Constant( 'GL_PACK_RESAMPLE_OML', 0x8984 )
glget.addGLGetConstant( GL_PACK_RESAMPLE_OML, (1,) )
GL_UNPACK_RESAMPLE_OML = constant.Constant( 'GL_UNPACK_RESAMPLE_OML', 0x8985 )
glget.addGLGetConstant( GL_UNPACK_RESAMPLE_OML, (1,) )
GL_RESAMPLE_REPLICATE_OML = constant.Constant( 'GL_RESAMPLE_REPLICATE_OML', 0x8986 )
GL_RESAMPLE_ZERO_FILL_OML = constant.Constant( 'GL_RESAMPLE_ZERO_FILL_OML', 0x8987 )
GL_RESAMPLE_AVERAGE_OML = constant.Constant( 'GL_RESAMPLE_AVERAGE_OML', 0x8988 )
GL_RESAMPLE_DECIMATE_OML = constant.Constant( 'GL_RESAMPLE_DECIMATE_OML', 0x8989 )


def glInitResampleOML():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.secondary_color

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_secondary_color'
_DEPRECATED = False
GL_COLOR_SUM_EXT = constant.Constant( 'GL_COLOR_SUM_EXT', 0x8458 )
glget.addGLGetConstant( GL_COLOR_SUM_EXT, (1,) )
GL_CURRENT_SECONDARY_COLOR_EXT = constant.Constant( 'GL_CURRENT_SECONDARY_COLOR_EXT', 0x8459 )
glget.addGLGetConstant( GL_CURRENT_SECONDARY_COLOR_EXT, (1,) )
GL_SECONDARY_COLOR_ARRAY_SIZE_EXT = constant.Constant( 'GL_SECONDARY_COLOR_ARRAY_SIZE_EXT', 0x845A )
glget.addGLGetConstant( GL_SECONDARY_COLOR_ARRAY_SIZE_EXT, (1,) )
GL_SECONDARY_COLOR_ARRAY_TYPE_EXT = constant.Constant( 'GL_SECONDARY_COLOR_ARRAY_TYPE_EXT', 0x845B )
glget.addGLGetConstant( GL_SECONDARY_COLOR_ARRAY_TYPE_EXT, (1,) )
GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT = constant.Constant( 'GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT', 0x845C )
glget.addGLGetConstant( GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT, (1,) )
GL_SECONDARY_COLOR_ARRAY_POINTER_EXT = constant.Constant( 'GL_SECONDARY_COLOR_ARRAY_POINTER_EXT', 0x845D )
GL_SECONDARY_COLOR_ARRAY_EXT = constant.Constant( 'GL_SECONDARY_COLOR_ARRAY_EXT', 0x845E )
glSecondaryColor3bEXT = platform.createExtensionFunction( 
'glSecondaryColor3bEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLbyte,constants.GLbyte,constants.GLbyte,),
doc='glSecondaryColor3bEXT(GLbyte(red), GLbyte(green), GLbyte(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glSecondaryColor3bvEXT = platform.createExtensionFunction( 
'glSecondaryColor3bvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLbyteArray,),
doc='glSecondaryColor3bvEXT(GLbyteArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glSecondaryColor3dEXT = platform.createExtensionFunction( 
'glSecondaryColor3dEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glSecondaryColor3dEXT(GLdouble(red), GLdouble(green), GLdouble(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glSecondaryColor3dvEXT = platform.createExtensionFunction( 
'glSecondaryColor3dvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glSecondaryColor3dvEXT(GLdoubleArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glSecondaryColor3fEXT = platform.createExtensionFunction( 
'glSecondaryColor3fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glSecondaryColor3fEXT(GLfloat(red), GLfloat(green), GLfloat(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glSecondaryColor3fvEXT = platform.createExtensionFunction( 
'glSecondaryColor3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glSecondaryColor3fvEXT(GLfloatArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glSecondaryColor3iEXT = platform.createExtensionFunction( 
'glSecondaryColor3iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,),
doc='glSecondaryColor3iEXT(GLint(red), GLint(green), GLint(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glSecondaryColor3ivEXT = platform.createExtensionFunction( 
'glSecondaryColor3ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLintArray,),
doc='glSecondaryColor3ivEXT(GLintArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glSecondaryColor3sEXT = platform.createExtensionFunction( 
'glSecondaryColor3sEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glSecondaryColor3sEXT(GLshort(red), GLshort(green), GLshort(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glSecondaryColor3svEXT = platform.createExtensionFunction( 
'glSecondaryColor3svEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLshortArray,),
doc='glSecondaryColor3svEXT(GLshortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glSecondaryColor3ubEXT = platform.createExtensionFunction( 
'glSecondaryColor3ubEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLubyte,constants.GLubyte,constants.GLubyte,),
doc='glSecondaryColor3ubEXT(GLubyte(red), GLubyte(green), GLubyte(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glSecondaryColor3ubvEXT = platform.createExtensionFunction( 
'glSecondaryColor3ubvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLubyteArray,),
doc='glSecondaryColor3ubvEXT(GLubyteArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glSecondaryColor3uiEXT = platform.createExtensionFunction( 
'glSecondaryColor3uiEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glSecondaryColor3uiEXT(GLuint(red), GLuint(green), GLuint(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glSecondaryColor3uivEXT = platform.createExtensionFunction( 
'glSecondaryColor3uivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,),
doc='glSecondaryColor3uivEXT(GLuintArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glSecondaryColor3usEXT = platform.createExtensionFunction( 
'glSecondaryColor3usEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLushort,constants.GLushort,constants.GLushort,),
doc='glSecondaryColor3usEXT(GLushort(red), GLushort(green), GLushort(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glSecondaryColor3usvEXT = platform.createExtensionFunction( 
'glSecondaryColor3usvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glSecondaryColor3usvEXT(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glSecondaryColorPointerEXT = platform.createExtensionFunction( 
'glSecondaryColorPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glSecondaryColorPointerEXT(GLint(size), GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('size','type','stride','pointer',),
deprecated=_DEPRECATED,
)


def glInitSecondaryColorEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_2_1

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_2_1'
_DEPRECATED = False
GL_PIXEL_PACK_BUFFER = constant.Constant( 'GL_PIXEL_PACK_BUFFER', 0x88EB )
GL_PIXEL_UNPACK_BUFFER = constant.Constant( 'GL_PIXEL_UNPACK_BUFFER', 0x88EC )
GL_PIXEL_PACK_BUFFER_BINDING = constant.Constant( 'GL_PIXEL_PACK_BUFFER_BINDING', 0x88ED )
GL_PIXEL_UNPACK_BUFFER_BINDING = constant.Constant( 'GL_PIXEL_UNPACK_BUFFER_BINDING', 0x88EF )
GL_FLOAT_MAT2x3 = constant.Constant( 'GL_FLOAT_MAT2x3', 0x8B65 )
GL_FLOAT_MAT2x4 = constant.Constant( 'GL_FLOAT_MAT2x4', 0x8B66 )
GL_FLOAT_MAT3x2 = constant.Constant( 'GL_FLOAT_MAT3x2', 0x8B67 )
GL_FLOAT_MAT3x4 = constant.Constant( 'GL_FLOAT_MAT3x4', 0x8B68 )
GL_FLOAT_MAT4x2 = constant.Constant( 'GL_FLOAT_MAT4x2', 0x8B69 )
GL_FLOAT_MAT4x3 = constant.Constant( 'GL_FLOAT_MAT4x3', 0x8B6A )
GL_SRGB = constant.Constant( 'GL_SRGB', 0x8C40 )
GL_SRGB8 = constant.Constant( 'GL_SRGB8', 0x8C41 )
GL_SRGB_ALPHA = constant.Constant( 'GL_SRGB_ALPHA', 0x8C42 )
GL_SRGB8_ALPHA8 = constant.Constant( 'GL_SRGB8_ALPHA8', 0x8C43 )
GL_COMPRESSED_SRGB = constant.Constant( 'GL_COMPRESSED_SRGB', 0x8C48 )
GL_COMPRESSED_SRGB_ALPHA = constant.Constant( 'GL_COMPRESSED_SRGB_ALPHA', 0x8C49 )
glUniformMatrix2x3fv = platform.createExtensionFunction( 
'glUniformMatrix2x3fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glUniformMatrix2x3fv(GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glUniformMatrix3x2fv = platform.createExtensionFunction( 
'glUniformMatrix3x2fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glUniformMatrix3x2fv(GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glUniformMatrix2x4fv = platform.createExtensionFunction( 
'glUniformMatrix2x4fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glUniformMatrix2x4fv(GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glUniformMatrix4x2fv = platform.createExtensionFunction( 
'glUniformMatrix4x2fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glUniformMatrix4x2fv(GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glUniformMatrix3x4fv = platform.createExtensionFunction( 
'glUniformMatrix3x4fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glUniformMatrix3x4fv(GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glUniformMatrix4x3fv = platform.createExtensionFunction( 
'glUniformMatrix4x3fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glUniformMatrix4x3fv(GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('location','count','transpose','value',),
deprecated=_DEPRECATED,
)
# import legacy entry points to allow checking for bool(entryPoint)
from OpenGL.raw.GL.VERSION.GL_2_1_DEPRECATED import *



'''OpenGL extension NV.vertex_buffer_unified_memory

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_vertex_buffer_unified_memory'
_DEPRECATED = False
GL_VERTEX_ATTRIB_ARRAY_UNIFIED_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_UNIFIED_NV', 0x8F1E )
GL_ELEMENT_ARRAY_UNIFIED_NV = constant.Constant( 'GL_ELEMENT_ARRAY_UNIFIED_NV', 0x8F1F )
GL_VERTEX_ATTRIB_ARRAY_ADDRESS_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_ADDRESS_NV', 0x8F20 )
GL_VERTEX_ARRAY_ADDRESS_NV = constant.Constant( 'GL_VERTEX_ARRAY_ADDRESS_NV', 0x8F21 )
GL_NORMAL_ARRAY_ADDRESS_NV = constant.Constant( 'GL_NORMAL_ARRAY_ADDRESS_NV', 0x8F22 )
GL_COLOR_ARRAY_ADDRESS_NV = constant.Constant( 'GL_COLOR_ARRAY_ADDRESS_NV', 0x8F23 )
GL_INDEX_ARRAY_ADDRESS_NV = constant.Constant( 'GL_INDEX_ARRAY_ADDRESS_NV', 0x8F24 )
GL_TEXTURE_COORD_ARRAY_ADDRESS_NV = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_ADDRESS_NV', 0x8F25 )
GL_EDGE_FLAG_ARRAY_ADDRESS_NV = constant.Constant( 'GL_EDGE_FLAG_ARRAY_ADDRESS_NV', 0x8F26 )
GL_SECONDARY_COLOR_ARRAY_ADDRESS_NV = constant.Constant( 'GL_SECONDARY_COLOR_ARRAY_ADDRESS_NV', 0x8F27 )
GL_FOG_COORD_ARRAY_ADDRESS_NV = constant.Constant( 'GL_FOG_COORD_ARRAY_ADDRESS_NV', 0x8F28 )
GL_ELEMENT_ARRAY_ADDRESS_NV = constant.Constant( 'GL_ELEMENT_ARRAY_ADDRESS_NV', 0x8F29 )
GL_VERTEX_ATTRIB_ARRAY_LENGTH_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_LENGTH_NV', 0x8F2A )
GL_VERTEX_ARRAY_LENGTH_NV = constant.Constant( 'GL_VERTEX_ARRAY_LENGTH_NV', 0x8F2B )
glget.addGLGetConstant( GL_VERTEX_ARRAY_LENGTH_NV, (1,) )
GL_NORMAL_ARRAY_LENGTH_NV = constant.Constant( 'GL_NORMAL_ARRAY_LENGTH_NV', 0x8F2C )
glget.addGLGetConstant( GL_NORMAL_ARRAY_LENGTH_NV, (1,) )
GL_COLOR_ARRAY_LENGTH_NV = constant.Constant( 'GL_COLOR_ARRAY_LENGTH_NV', 0x8F2D )
glget.addGLGetConstant( GL_COLOR_ARRAY_LENGTH_NV, (1,) )
GL_INDEX_ARRAY_LENGTH_NV = constant.Constant( 'GL_INDEX_ARRAY_LENGTH_NV', 0x8F2E )
glget.addGLGetConstant( GL_INDEX_ARRAY_LENGTH_NV, (1,) )
GL_TEXTURE_COORD_ARRAY_LENGTH_NV = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_LENGTH_NV', 0x8F2F )
GL_EDGE_FLAG_ARRAY_LENGTH_NV = constant.Constant( 'GL_EDGE_FLAG_ARRAY_LENGTH_NV', 0x8F30 )
glget.addGLGetConstant( GL_EDGE_FLAG_ARRAY_LENGTH_NV, (1,) )
GL_SECONDARY_COLOR_ARRAY_LENGTH_NV = constant.Constant( 'GL_SECONDARY_COLOR_ARRAY_LENGTH_NV', 0x8F31 )
glget.addGLGetConstant( GL_SECONDARY_COLOR_ARRAY_LENGTH_NV, (1,) )
GL_FOG_COORD_ARRAY_LENGTH_NV = constant.Constant( 'GL_FOG_COORD_ARRAY_LENGTH_NV', 0x8F32 )
glget.addGLGetConstant( GL_FOG_COORD_ARRAY_LENGTH_NV, (1,) )
GL_ELEMENT_ARRAY_LENGTH_NV = constant.Constant( 'GL_ELEMENT_ARRAY_LENGTH_NV', 0x8F33 )
glget.addGLGetConstant( GL_ELEMENT_ARRAY_LENGTH_NV, (1,) )
glBufferAddressRangeNV = platform.createExtensionFunction( 
'glBufferAddressRangeNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint64EXT,constants.GLsizeiptr,),
doc='glBufferAddressRangeNV(GLenum(pname), GLuint(index), GLuint64EXT(address), GLsizeiptr(length)) -> None',
argNames=('pname','index','address','length',),
deprecated=_DEPRECATED,
)

glVertexFormatNV = platform.createExtensionFunction( 
'glVertexFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,),
doc='glVertexFormatNV(GLint(size), GLenum(type), GLsizei(stride)) -> None',
argNames=('size','type','stride',),
deprecated=_DEPRECATED,
)

glNormalFormatNV = platform.createExtensionFunction( 
'glNormalFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,),
doc='glNormalFormatNV(GLenum(type), GLsizei(stride)) -> None',
argNames=('type','stride',),
deprecated=_DEPRECATED,
)

glColorFormatNV = platform.createExtensionFunction( 
'glColorFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,),
doc='glColorFormatNV(GLint(size), GLenum(type), GLsizei(stride)) -> None',
argNames=('size','type','stride',),
deprecated=_DEPRECATED,
)

glIndexFormatNV = platform.createExtensionFunction( 
'glIndexFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,),
doc='glIndexFormatNV(GLenum(type), GLsizei(stride)) -> None',
argNames=('type','stride',),
deprecated=_DEPRECATED,
)

glTexCoordFormatNV = platform.createExtensionFunction( 
'glTexCoordFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,),
doc='glTexCoordFormatNV(GLint(size), GLenum(type), GLsizei(stride)) -> None',
argNames=('size','type','stride',),
deprecated=_DEPRECATED,
)

glEdgeFlagFormatNV = platform.createExtensionFunction( 
'glEdgeFlagFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,),
doc='glEdgeFlagFormatNV(GLsizei(stride)) -> None',
argNames=('stride',),
deprecated=_DEPRECATED,
)

glSecondaryColorFormatNV = platform.createExtensionFunction( 
'glSecondaryColorFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,),
doc='glSecondaryColorFormatNV(GLint(size), GLenum(type), GLsizei(stride)) -> None',
argNames=('size','type','stride',),
deprecated=_DEPRECATED,
)

glFogCoordFormatNV = platform.createExtensionFunction( 
'glFogCoordFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,),
doc='glFogCoordFormatNV(GLenum(type), GLsizei(stride)) -> None',
argNames=('type','stride',),
deprecated=_DEPRECATED,
)

glVertexAttribFormatNV = platform.createExtensionFunction( 
'glVertexAttribFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLenum,constants.GLboolean,constants.GLsizei,),
doc='glVertexAttribFormatNV(GLuint(index), GLint(size), GLenum(type), GLboolean(normalized), GLsizei(stride)) -> None',
argNames=('index','size','type','normalized','stride',),
deprecated=_DEPRECATED,
)

glVertexAttribIFormatNV = platform.createExtensionFunction( 
'glVertexAttribIFormatNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLenum,constants.GLsizei,),
doc='glVertexAttribIFormatNV(GLuint(index), GLint(size), GLenum(type), GLsizei(stride)) -> None',
argNames=('index','size','type','stride',),
deprecated=_DEPRECATED,
)

glGetIntegerui64i_vNV = platform.createExtensionFunction( 
'glGetIntegerui64i_vNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLuint64Array,),
doc='glGetIntegerui64i_vNV(GLenum(value), GLuint(index), GLuint64Array(result)) -> None',
argNames=('value','index','result',),
deprecated=_DEPRECATED,
)


def glInitVertexBufferUnifiedMemoryNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.depth_buffer_float

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_depth_buffer_float'
_DEPRECATED = False
GL_DEPTH_COMPONENT32F_NV = constant.Constant( 'GL_DEPTH_COMPONENT32F_NV', 0x8DAB )
GL_DEPTH32F_STENCIL8_NV = constant.Constant( 'GL_DEPTH32F_STENCIL8_NV', 0x8DAC )
GL_FLOAT_32_UNSIGNED_INT_24_8_REV_NV = constant.Constant( 'GL_FLOAT_32_UNSIGNED_INT_24_8_REV_NV', 0x8DAD )
GL_DEPTH_BUFFER_FLOAT_MODE_NV = constant.Constant( 'GL_DEPTH_BUFFER_FLOAT_MODE_NV', 0x8DAF )
glDepthRangedNV = platform.createExtensionFunction( 
'glDepthRangedNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,),
doc='glDepthRangedNV(GLdouble(zNear), GLdouble(zFar)) -> None',
argNames=('zNear','zFar',),
deprecated=_DEPRECATED,
)

glClearDepthdNV = platform.createExtensionFunction( 
'glClearDepthdNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,),
doc='glClearDepthdNV(GLdouble(depth)) -> None',
argNames=('depth',),
deprecated=_DEPRECATED,
)

glDepthBoundsdNV = platform.createExtensionFunction( 
'glDepthBoundsdNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,),
doc='glDepthBoundsdNV(GLdouble(zmin), GLdouble(zmax)) -> None',
argNames=('zmin','zmax',),
deprecated=_DEPRECATED,
)


def glInitDepthBufferFloatNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.impact_pixel_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_impact_pixel_texture'
_DEPRECATED = False
GL_PIXEL_TEX_GEN_Q_CEILING_SGIX = constant.Constant( 'GL_PIXEL_TEX_GEN_Q_CEILING_SGIX', 0x8184 )
GL_PIXEL_TEX_GEN_Q_ROUND_SGIX = constant.Constant( 'GL_PIXEL_TEX_GEN_Q_ROUND_SGIX', 0x8185 )
GL_PIXEL_TEX_GEN_Q_FLOOR_SGIX = constant.Constant( 'GL_PIXEL_TEX_GEN_Q_FLOOR_SGIX', 0x8186 )
GL_PIXEL_TEX_GEN_ALPHA_REPLACE_SGIX = constant.Constant( 'GL_PIXEL_TEX_GEN_ALPHA_REPLACE_SGIX', 0x8187 )
GL_PIXEL_TEX_GEN_ALPHA_NO_REPLACE_SGIX = constant.Constant( 'GL_PIXEL_TEX_GEN_ALPHA_NO_REPLACE_SGIX', 0x8188 )
GL_PIXEL_TEX_GEN_ALPHA_LS_SGIX = constant.Constant( 'GL_PIXEL_TEX_GEN_ALPHA_LS_SGIX', 0x8189 )
GL_PIXEL_TEX_GEN_ALPHA_MS_SGIX = constant.Constant( 'GL_PIXEL_TEX_GEN_ALPHA_MS_SGIX', 0x818A )


def glInitImpactPixelTextureSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.depth_texture

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.depth_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This is a clarification of the GL_SGIX_depth_texture extension.  The
	original overview follows:
	
	This extension defines a new depth texture format.  An important
	application of depth texture images is shadow casting, but separating
	this from the shadow extension allows for the potential use of depth
	textures in other applications such as image-based rendering or
	displacement mapping.  This extension does not define new depth-texture
	environment functions, such as filtering or applying the depth values
	computed from a texture but leaves this to other extensions, such as
	the shadow extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/depth_texture.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.depth_texture import *
### END AUTOGENERATED SECTION


'''OpenGL extension NV.explicit_multisample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_explicit_multisample'
_DEPRECATED = False
GL_SAMPLE_POSITION_NV = constant.Constant( 'GL_SAMPLE_POSITION_NV', 0x8E50 )
GL_SAMPLE_MASK_NV = constant.Constant( 'GL_SAMPLE_MASK_NV', 0x8E51 )
GL_SAMPLE_MASK_VALUE_NV = constant.Constant( 'GL_SAMPLE_MASK_VALUE_NV', 0x8E52 )
GL_TEXTURE_BINDING_RENDERBUFFER_NV = constant.Constant( 'GL_TEXTURE_BINDING_RENDERBUFFER_NV', 0x8E53 )
glget.addGLGetConstant( GL_TEXTURE_BINDING_RENDERBUFFER_NV, (1,) )
GL_TEXTURE_RENDERBUFFER_DATA_STORE_BINDING_NV = constant.Constant( 'GL_TEXTURE_RENDERBUFFER_DATA_STORE_BINDING_NV', 0x8E54 )
glget.addGLGetConstant( GL_TEXTURE_RENDERBUFFER_DATA_STORE_BINDING_NV, (1,) )
GL_TEXTURE_RENDERBUFFER_NV = constant.Constant( 'GL_TEXTURE_RENDERBUFFER_NV', 0x8E55 )
GL_SAMPLER_RENDERBUFFER_NV = constant.Constant( 'GL_SAMPLER_RENDERBUFFER_NV', 0x8E56 )
GL_INT_SAMPLER_RENDERBUFFER_NV = constant.Constant( 'GL_INT_SAMPLER_RENDERBUFFER_NV', 0x8E57 )
GL_UNSIGNED_INT_SAMPLER_RENDERBUFFER_NV = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_RENDERBUFFER_NV', 0x8E58 )
GL_MAX_SAMPLE_MASK_WORDS_NV = constant.Constant( 'GL_MAX_SAMPLE_MASK_WORDS_NV', 0x8E59 )
glget.addGLGetConstant( GL_MAX_SAMPLE_MASK_WORDS_NV, (1,) )
glGetMultisamplefvNV = platform.createExtensionFunction( 
'glGetMultisamplefvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glGetMultisamplefvNV(GLenum(pname), GLuint(index), GLfloatArray(val)) -> None',
argNames=('pname','index','val',),
deprecated=_DEPRECATED,
)

glSampleMaskIndexedNV = platform.createExtensionFunction( 
'glSampleMaskIndexedNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLbitfield,),
doc='glSampleMaskIndexedNV(GLuint(index), GLbitfield(mask)) -> None',
argNames=('index','mask',),
deprecated=_DEPRECATED,
)

glTexRenderbufferNV = platform.createExtensionFunction( 
'glTexRenderbufferNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glTexRenderbufferNV(GLenum(target), GLuint(renderbuffer)) -> None',
argNames=('target','renderbuffer',),
deprecated=_DEPRECATED,
)


def glInitExplicitMultisampleNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.draw_buffers

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_draw_buffers'
_DEPRECATED = False
GL_MAX_DRAW_BUFFERS_ARB = constant.Constant( 'GL_MAX_DRAW_BUFFERS_ARB', 0x8824 )
glget.addGLGetConstant( GL_MAX_DRAW_BUFFERS_ARB, (1,) )
GL_DRAW_BUFFER0_ARB = constant.Constant( 'GL_DRAW_BUFFER0_ARB', 0x8825 )
glget.addGLGetConstant( GL_DRAW_BUFFER0_ARB, (1,) )
GL_DRAW_BUFFER1_ARB = constant.Constant( 'GL_DRAW_BUFFER1_ARB', 0x8826 )
glget.addGLGetConstant( GL_DRAW_BUFFER1_ARB, (1,) )
GL_DRAW_BUFFER2_ARB = constant.Constant( 'GL_DRAW_BUFFER2_ARB', 0x8827 )
glget.addGLGetConstant( GL_DRAW_BUFFER2_ARB, (1,) )
GL_DRAW_BUFFER3_ARB = constant.Constant( 'GL_DRAW_BUFFER3_ARB', 0x8828 )
glget.addGLGetConstant( GL_DRAW_BUFFER3_ARB, (1,) )
GL_DRAW_BUFFER4_ARB = constant.Constant( 'GL_DRAW_BUFFER4_ARB', 0x8829 )
glget.addGLGetConstant( GL_DRAW_BUFFER4_ARB, (1,) )
GL_DRAW_BUFFER5_ARB = constant.Constant( 'GL_DRAW_BUFFER5_ARB', 0x882A )
glget.addGLGetConstant( GL_DRAW_BUFFER5_ARB, (1,) )
GL_DRAW_BUFFER6_ARB = constant.Constant( 'GL_DRAW_BUFFER6_ARB', 0x882B )
glget.addGLGetConstant( GL_DRAW_BUFFER6_ARB, (1,) )
GL_DRAW_BUFFER7_ARB = constant.Constant( 'GL_DRAW_BUFFER7_ARB', 0x882C )
glget.addGLGetConstant( GL_DRAW_BUFFER7_ARB, (1,) )
GL_DRAW_BUFFER8_ARB = constant.Constant( 'GL_DRAW_BUFFER8_ARB', 0x882D )
glget.addGLGetConstant( GL_DRAW_BUFFER8_ARB, (1,) )
GL_DRAW_BUFFER9_ARB = constant.Constant( 'GL_DRAW_BUFFER9_ARB', 0x882E )
glget.addGLGetConstant( GL_DRAW_BUFFER9_ARB, (1,) )
GL_DRAW_BUFFER10_ARB = constant.Constant( 'GL_DRAW_BUFFER10_ARB', 0x882F )
glget.addGLGetConstant( GL_DRAW_BUFFER10_ARB, (1,) )
GL_DRAW_BUFFER11_ARB = constant.Constant( 'GL_DRAW_BUFFER11_ARB', 0x8830 )
glget.addGLGetConstant( GL_DRAW_BUFFER11_ARB, (1,) )
GL_DRAW_BUFFER12_ARB = constant.Constant( 'GL_DRAW_BUFFER12_ARB', 0x8831 )
glget.addGLGetConstant( GL_DRAW_BUFFER12_ARB, (1,) )
GL_DRAW_BUFFER13_ARB = constant.Constant( 'GL_DRAW_BUFFER13_ARB', 0x8832 )
glget.addGLGetConstant( GL_DRAW_BUFFER13_ARB, (1,) )
GL_DRAW_BUFFER14_ARB = constant.Constant( 'GL_DRAW_BUFFER14_ARB', 0x8833 )
glget.addGLGetConstant( GL_DRAW_BUFFER14_ARB, (1,) )
GL_DRAW_BUFFER15_ARB = constant.Constant( 'GL_DRAW_BUFFER15_ARB', 0x8834 )
glget.addGLGetConstant( GL_DRAW_BUFFER15_ARB, (1,) )
glDrawBuffersARB = platform.createExtensionFunction( 
'glDrawBuffersARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDrawBuffersARB(GLsizei(n), GLuintArray(bufs)) -> None',
argNames=('n','bufs',),
deprecated=_DEPRECATED,
)


def glInitDrawBuffersARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.depth_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_depth_texture'
_DEPRECATED = False
GL_DEPTH_COMPONENT16_SGIX = constant.Constant( 'GL_DEPTH_COMPONENT16_SGIX', 0x81A5 )
GL_DEPTH_COMPONENT24_SGIX = constant.Constant( 'GL_DEPTH_COMPONENT24_SGIX', 0x81A6 )
GL_DEPTH_COMPONENT32_SGIX = constant.Constant( 'GL_DEPTH_COMPONENT32_SGIX', 0x81A7 )


def glInitDepthTextureSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



#!/usr/bin/python

import pygame
from pygame.locals import *
from OpenGL.GL import *
from OpenGL.GLU import *

def main():
    pygame.init()
    pygame.display.set_mode((800,600), pygame.OPENGL|
        pygame.DOUBLEBUF)
    glClearColor(1.0, 0.0, 0.0, 1.0)
    glClear(GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT)

    done = False

    while not done:
        for i in range(0,50000):
            modelview_matrix = glGetFloatv(GL_MODELVIEW_MATRIX)
            if not i % 500:
                print '.',
        print
        pygame.display.flip()

        eventlist = pygame.event.get()
        for event in eventlist:
            if event.type == QUIT or event.type == KEYDOWN and event.key == K_ESCAPE:
                done = True

if __name__ == '__main__':
    main()


'''OpenGL extension EXT.draw_instanced

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_draw_instanced'
_DEPRECATED = False

glDrawArraysInstancedEXT = platform.createExtensionFunction( 
'glDrawArraysInstancedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glDrawArraysInstancedEXT(GLenum(mode), GLint(start), GLsizei(count), GLsizei(primcount)) -> None',
argNames=('mode','start','count','primcount',),
deprecated=_DEPRECATED,
)

glDrawElementsInstancedEXT = platform.createExtensionFunction( 
'glDrawElementsInstancedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLenum,ctypes.c_void_p,constants.GLsizei,),
doc='glDrawElementsInstancedEXT(GLenum(mode), GLsizei(count), GLenum(type), c_void_p(indices), GLsizei(primcount)) -> None',
argNames=('mode','count','type','indices','primcount',),
deprecated=_DEPRECATED,
)


def glInitDrawInstancedEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



from OpenGL.GL import *
from OpenGL.GLUT import *
from OpenGL.GLU import *
import time

resX,resY = (400,300 )

def display( ):
    glutSetWindow(window);
    glClearColor (0.0, 0.0, (time.time()%1.0)/1.0, 0.0)
    glClear (GL_COLOR_BUFFER_BIT)
    glFlush ()
    glutSwapBuffers()


if __name__ == "__main__":
    glutInit([])
    glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH)

    glutInitWindowSize(resX, resY)

    glutInitWindowPosition(0, 0)
    window = glutCreateWindow("hello")
    glutDisplayFunc(display)
    for name in (GL_VENDOR,GL_RENDERER,GL_SHADING_LANGUAGE_VERSION,GL_EXTENSIONS):
        print name,glGetString(name)
    
    glutMainLoop()
    



'''OpenGL extension EXT.texture_env_dot3

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_env_dot3'
_DEPRECATED = False
GL_DOT3_RGB_EXT = constant.Constant( 'GL_DOT3_RGB_EXT', 0x8740 )
GL_DOT3_RGBA_EXT = constant.Constant( 'GL_DOT3_RGBA_EXT', 0x8741 )


def glInitTextureEnvDot3EXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture_array

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_array'
_DEPRECATED = False
GL_TEXTURE_1D_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_1D_ARRAY_EXT', 0x8C18 )
GL_PROXY_TEXTURE_1D_ARRAY_EXT = constant.Constant( 'GL_PROXY_TEXTURE_1D_ARRAY_EXT', 0x8C19 )
GL_TEXTURE_2D_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_2D_ARRAY_EXT', 0x8C1A )
GL_PROXY_TEXTURE_2D_ARRAY_EXT = constant.Constant( 'GL_PROXY_TEXTURE_2D_ARRAY_EXT', 0x8C1B )
GL_TEXTURE_BINDING_1D_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_BINDING_1D_ARRAY_EXT', 0x8C1C )
glget.addGLGetConstant( GL_TEXTURE_BINDING_1D_ARRAY_EXT, (1,) )
GL_TEXTURE_BINDING_2D_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_BINDING_2D_ARRAY_EXT', 0x8C1D )
glget.addGLGetConstant( GL_TEXTURE_BINDING_2D_ARRAY_EXT, (1,) )
GL_MAX_ARRAY_TEXTURE_LAYERS_EXT = constant.Constant( 'GL_MAX_ARRAY_TEXTURE_LAYERS_EXT', 0x88FF )
glget.addGLGetConstant( GL_MAX_ARRAY_TEXTURE_LAYERS_EXT, (1,) )
GL_COMPARE_REF_DEPTH_TO_TEXTURE_EXT = constant.Constant( 'GL_COMPARE_REF_DEPTH_TO_TEXTURE_EXT', 0x884E )


def glInitTextureArrayEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension OES.read_format

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_OES_read_format'
_DEPRECATED = False
GL_IMPLEMENTATION_COLOR_READ_TYPE_OES = constant.Constant( 'GL_IMPLEMENTATION_COLOR_READ_TYPE_OES', 0x8B9A )
GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES = constant.Constant( 'GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES', 0x8B9B )


def glInitReadFormatOES():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension GLEXT.GL_64_TYPES_DEFINED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_GLEXT_GL_64_TYPES_DEFINED'
_DEPRECATED = False



def glInitGl64TypesDefinedGLEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
